//---------------------------------------------------------------------------
// TestAllometry.cpp
//---------------------------------------------------------------------------
#include "TestAllometry.h"
#include "TreePopulation.h"
#include "SimManager.h"
#include "Allometry.h"
#include <fstream.h>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestAllometry()
/////////////////////////////////////////////////////////////////////////////
void clTestAllometry::TestAllometry()
{

  clSimManager *p_oSimManager = new clSimManager(2, 4, "");

  TestNormalProcessing(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}


/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestAllometry::TestNormalProcessing(clSimManager *p_oSimManager)
{
  clTreePopulation * p_oPop;
  clAllometry *p_oAllom;
  float fDiam, fDBH, fHeight, fCanRad, fCanDepth, fExpected;
  int iSp;

  //Set up our run and get the tree popluation pointer
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oAllom = p_oPop->GetAllometryObject();

  ///////////////////////////////
  // Test CalcAdultHeight
  ///////////////////////////////
  fDBH = 32.4;
  iSp = 0;  fExpected = 25.00762914;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 22.04817374;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 26.38284845;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 31.104;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 15.41705714;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 41.22;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -0.011514286;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -0.9;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = -12;
  iSp = 0;  fExpected = -15.10730649;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = -11.45735156;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = -14.84771678;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = -11.52;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -5.7258;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -16.5;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 39.48;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 39.54;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 45;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 39.48;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 39.54;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 45;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.35;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 4.128E-28;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -0.011514286;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -0.9;
  fHeight = p_oAllom->CalcAdultHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcAdultDbh
  ///////////////////////////////
  fHeight = 14.789;
  iSp = 0;  fExpected = 14.53386519;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 17.99617465;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = 13.99228843;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 15.40520833;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 31.08108;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 12.06846154;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 0;
  iSp = 0;  fExpected = -1.163640157;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -1.441457116;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -1.158144771;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.02418;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.692307692;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = -35.778;
  iSp = 0;  fExpected = -22.7398273;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -28.18030908;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -23.40309388;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = -37.26875;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = -75.10962;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = -26.82923077;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 4.30E-28;
  iSp = 0;  fExpected = -1.163640157;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -1.441457116;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -1.158144771;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 4.47917E-28;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.02418;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.692307692;
  fDBH = p_oAllom->CalcAdultDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcAdultCanRadius
  ///////////////////////////////
  fDBH = 45.633;
  iSp = 0;  fExpected = 1.709713982;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.8018662;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.616825759;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 10;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 10;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 10;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.28734E-26;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.6402E-29;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.90665E-32;
  fCanRad = p_oAllom->CalcAdultCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcAdultCanDepth
  ///////////////////////////////
  fDBH = 45.633;
  iSp = 0;  fExpected = 17.751237;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.485921035;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 10.5883926;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 1.34205E+12;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 683529.6629;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 65390717488;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.6727E-28;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 7.63101E-15;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 7.97261E-26;
  fCanDepth = p_oAllom->CalcAdultCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSaplingHeight
  ///////////////////////////////
  fDBH = 5.7332;
  iSp = 0;  fExpected = 7.35679411;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 4.0207344;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 5.982;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 0.31475268;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 3.3148;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 7.459508556;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 1.35;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 1.2;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.77;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -0.507333333;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 1.35;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);



  fDBH = -8.907;
  iSp = 0;  fExpected = -10.28543535;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = -3.182244;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = -7.327272727;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = -0.4889943;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -6.445333333;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -10.17209953;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 39.48;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 39.54;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 45;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 39.48;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 39.54;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 45;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.35;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 1.2;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.77;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 2.3607E-29;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -0.507333333;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 1.35;
  fHeight = p_oAllom->CalcSaplingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSaplingDbh
  ///////////////////////////////
  fHeight = 4.56223;
  iSp = 0;  fExpected = 2.943327933;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 6.833800813;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = 4.171453;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 83.1007286;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 7.604345;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 2.906427113;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 0;
  iSp = 0;  fExpected = -1.163640157;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -2.43902439;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -0.847;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.761;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = -1.158144771;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = -2.4123;
  iSp = 0;  fExpected = -3.147179441;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -7.342073171;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -3.50053;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = -43.93989071;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = -2.85745;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = -3.143665643;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 4.30E-28;
  iSp = 0;  fExpected = -1.163640157;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = -2.43902439;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -0.847;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 7.83242E-27;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.761;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = -1.158144771;
  fDBH = p_oAllom->CalcSaplingDbh(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSaplingCanRadius
  ///////////////////////////////
  fDBH = 7.0375;
  iSp = 0;  fExpected = 0.317869539;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.4321025;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.206831435;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 10;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 10;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 10;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.28734E-26;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.6402E-29;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.90665E-32;
  fCanRad = p_oAllom->CalcSaplingCanRadius(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanRad)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSaplingCanDepth
  ///////////////////////////////
  fDBH = 7.0375;
  iSp = 0;  fExpected = 2.7375875;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.976240954;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.968590949;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 1.34205E+12;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 683529.6629;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 65390717488;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 1.6727E-28;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 7.63101E-15;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 7.97261E-26;
  fCanDepth = p_oAllom->CalcSaplingCanDepth(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSeedlingHeight
  ///////////////////////////////
  fDBH = 0.89485;
  iSp = 0;  fExpected = 1.003688643;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.089233333;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 6.896898695;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 0.861651065;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 6.8425;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.1988758;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);



  fDBH = 0;
  iSp = 0;  fExpected = 0.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = -0.507333333;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -37.9;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -0.9;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = -2.94893;
  iSp = 0;  fExpected = -3.081477349;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = -2.473286667;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = -39.85381123;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = -283.9524697;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -185.3465;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -395.74125;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 30.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = 39.54;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 30.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 39.48;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = 39.54;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = 45;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 0.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 1;  fExpected = -0.507333333;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.1;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 3;  fExpected = 4.14047E-28;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 4;  fExpected = -37.9;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  iSp = 5;  fExpected = -0.9;
  fHeight = p_oAllom->CalcSeedlingHeight(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fHeight)/fExpected < 0.01);

  ///////////////////////////////
  // Test CalcSeedlingDiam10
  ///////////////////////////////
  fHeight = 0.8747;
  iSp = 0;  fExpected = 0.765436196;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.07305;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = 0.091127165;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 0.908401703;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.775494;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 1.44519544;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 0;
  iSp = 0;  fExpected = -0.09736074;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.761;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -0.011591049;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 0;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.758;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.732899023;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = -0.35234;
  iSp = 0;  fExpected = -0.437842505;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.23249;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -0.052126286;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = -0.003659155;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.7509532;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.445977199;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);


  fHeight = 4.30E-28;
  iSp = 0;  fExpected = -0.09736074;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 1;  fExpected = 0.761;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 2;  fExpected = -0.011591049;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 3;  fExpected = 4.46568E-28;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 4;  fExpected = 0.758;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  iSp = 5;  fExpected = 0.732899023;
  fDBH = p_oAllom->CalcSeedlingDiam10(fHeight, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fDBH)/fExpected < 0.01);

  ///////////////////////////////
  // Test ConvertDiam10ToDbh
  ///////////////////////////////
  fDBH = 2.5938;
  iSp = 0;  fExpected = 2.07711504;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 1.54175472;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 1.83096342;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = -9.94983;
  iSp = 0;  fExpected = -7.967823864;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = -5.914178952;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = -7.023584997;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 2.76276E+12;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.05068E+12;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 2.43536E+12;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 3.44E-28;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 2.55592E-28;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 3.03537E-28;
  fCanDepth = p_oAllom->ConvertDiam10ToDbh(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  ///////////////////////////////
  // Test ConvertDbhToDiam10
  ///////////////////////////////
  fDBH = 10.2342;
  iSp = 0;  fExpected = 12.77997003;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 17.21769852;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 14.49808755;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 0;
  iSp = 0;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 0;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = -33.98034;
  iSp = 0;  fExpected = -42.43299201;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = -57.16746299;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = -48.13761156;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 3.45E+12;
  iSp = 0;  fExpected = 4.30819E+12;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 5.80417E+12;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 4.88738E+12;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);


  fDBH = 4.30E-28;
  iSp = 0;  fExpected = 5.36963E-28;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 1;  fExpected = 7.23419E-28;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  iSp = 2;  fExpected = 6.09151E-28;
  fCanDepth = p_oAllom->ConvertDbhToDiam10(fDBH, iSp);
  CPPUNIT_ASSERT(fabs(fExpected - fCanDepth)/fExpected < 0.01);

  ///////////////////////////////
  // Test parameter file reading
  ///////////////////////////////
  //These files should simply load without problems.
  p_oSimManager->ReadFile( WriteXMLFile2() );
  p_oSimManager->ReadFile( WriteXMLFile3() );
  p_oSimManager->ReadFile( WriteXMLFile4() );
}

/////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestAllometry::TestErrorProcessing(clSimManager *p_oSimManager)
{
  clTreePopulation * p_oPop;
  clAllometry *p_oAllom;
  float fDiam, fDBH, fHeight, fExpected;
  int iSp;

  //////////////////////////////
  // Part 1:  Bad arguments to the allometry functions
  //////////////////////////////
  //Set up our run and get the tree popluation pointer
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oAllom = p_oPop->GetAllometryObject();

  try {
    //Invalid species to CalcAdultHeight
    p_oAllom->CalcAdultHeight(10.0, -1);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcAdultHeight.");
  }
  catch (modelErr &err) {;}

  try {
    //Invalid species to CalcAdultDbh
    p_oAllom->CalcAdultDbh(10.0, 10);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcAdultDbh.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcSaplingHeight
    p_oAllom->CalcSaplingHeight(10.0, -10);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSaplingHeight.");
  }
  catch (modelErr &err) {;}

  try {
    //Invalid species to CalcSaplingDbh
    p_oAllom->CalcSaplingDbh(10.0, 9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSaplingDbh.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcSeedlingHeight
    p_oAllom->CalcSeedlingHeight(10.0, -10);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSeedlingHeight.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcSeedlingDiam10
    p_oAllom->CalcSeedlingDiam10(10.0, 9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSeedlingDiam10.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcAdultCanRadius
    p_oAllom->CalcAdultCanRadius(10.0, 9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcAdultCanRadius.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcSaplingCanRadius
    p_oAllom->CalcSaplingCanRadius(10.0, 9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSaplingCanRadius.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcAdultCanDepth
    p_oAllom->CalcAdultCanDepth(10.0, -9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcAdultCanDepth.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to CalcSaplingCanDepth
    p_oAllom->CalcSaplingCanDepth(10.0, 9);
    CppUnit::Asserter::fail("Didn't catch invalid species for CalcSaplingCanDepth.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to ConvertDiam10ToDbh
    p_oAllom->ConvertDiam10ToDbh(10.0, 1985);
    CppUnit::Asserter::fail("Didn't catch invalid species for ConvertDiam10ToDbh.");
  }
  catch (modelErr &err) {;}
  try {
    //Invalid species to ConvertDbhToDiam10
    p_oAllom->ConvertDbhToDiam10(10.0, 1985);
    CppUnit::Asserter::fail("Didn't catch invalid species for ConvertDbhToDiam10.");
  }
  catch (modelErr &err) {;}
  try {
    //Height too large to CalcAdultDbh
    p_oAllom->CalcAdultDbh(100.0, 1);
    CppUnit::Asserter::fail("Didn't catch invalid height for CalcAdultDbh.");
  }
  catch (modelErr &err) {;}
  try {
    //Height too large to CalcSaplingDbh
    p_oAllom->CalcSaplingDbh(100.0, 0);
    CppUnit::Asserter::fail("Didn't catch invalid height for CalcSaplingDbh.");
  }
  catch (modelErr &err) {;}

  //////////////////////////////
  // Part 2:  Bad data in parameter files
  //////////////////////////////
  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }
  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }
  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile6.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile6.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile7.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile7.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile8.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile8.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile9());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile9.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile9.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile10());
    CppUnit::Asserter::fail("TestAllometry error processing didn't catch error for WriteXMLErrorFile10.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clAllometry::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestAllometry error processing caught wrong error for WriteXMLErrorFile10.");
    }
    ;
  }
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "<tr_species speciesName=\"Species_5\"/>"
       << "<tr_species speciesName=\"Species_6\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_5\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_6\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_5\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_6\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_5\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_6\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_4\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_5\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_6\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "<tr_creVal species=\"Species_4\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_5\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_6\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_5\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_6\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_4\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_5\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_6\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_4\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_5\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_6\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Species_6\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_5\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_6\">1</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_5\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_6\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_5\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_6\">1</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultLinearSlope>"
       << "<tr_alsVal species=\"Species_4\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_6\">1.3</tr_alsVal>"
       << "</tr_adultLinearSlope>"
       << "<tr_adultLinearIntercept>"
       << "<tr_aliVal species=\"Species_4\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_6\">-0.9</tr_aliVal>"
       << "</tr_adultLinearIntercept>"
       << "<tr_saplingLinearSlope>"
       << "<tr_salsVal species=\"Species_2\">0.492</tr_salsVal>"
       << "<tr_salsVal species=\"Species_4\">0.0549</tr_salsVal>"
       << "</tr_saplingLinearSlope>"
       << "<tr_saplingLinearIntercept>"
       << "<tr_saliVal species=\"Species_2\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_4\">0</tr_saliVal>"
       << "</tr_saplingLinearIntercept>"
       << "<tr_seedlingLinearSlope>"
       << "<tr_selsVal species=\"Species_4\">0.9629</tr_selsVal>"
       << "<tr_selsVal species=\"Species_6\">1.228</tr_selsVal>"
       << "</tr_seedlingLinearSlope>"
       << "<tr_seedlingLinearIntercept>"
       << "<tr_seliVal species=\"Species_4\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_6\">-0.9</tr_seliVal>"
       << "</tr_seedlingLinearIntercept>"
       << "<tr_adultReverseLinearSlope>"
       << "<tr_arlsVal species=\"Species_5\">2.1</tr_arlsVal>"
       << "</tr_adultReverseLinearSlope>"
       << "<tr_adultReverseLinearIntercept>"
       << "<tr_arliVal species=\"Species_5\">0.02418</tr_arliVal>"
       << "</tr_adultReverseLinearIntercept>"
       << "<tr_saplingReverseLinearSlope>"
       << "<tr_sarlsVal species=\"Species_5\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_3\">1.1</tr_sarlsVal>"
       << "</tr_saplingReverseLinearSlope>"
       << "<tr_saplingReverseLinearIntercept>"
       << "<tr_sarliVal species=\"Species_5\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_3\">-0.847</tr_sarliVal>"
       << "</tr_saplingReverseLinearIntercept>"
       << "<tr_seedlingReverseLinearSlope>"
       << "<tr_serlsVal species=\"Species_2\">1.5</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_5\">0.02</tr_serlsVal>"
       << "</tr_seedlingReverseLinearSlope>"
       << "<tr_seedlingReverseLinearIntercept>"
       << "<tr_serliVal species=\"Species_2\">0.761</tr_serliVal>"
       << "<tr_serliVal species=\"Species_5\">0.758</tr_serliVal>"
       << "</tr_seedlingReverseLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">1</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">1</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">1</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultLinearSlope>"
       << "<tr_alsVal species=\"Species_1\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_2\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_3\">1.3</tr_alsVal>"
       << "</tr_adultLinearSlope>"
       << "<tr_adultLinearIntercept>"
       << "<tr_aliVal species=\"Species_1\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_2\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_3\">0.9</tr_aliVal>"
       << "</tr_adultLinearIntercept>"
       << "<tr_saplingLinearSlope>"
       << "<tr_salsVal species=\"Species_2\">49.82</tr_salsVal>"
       << "<tr_salsVal species=\"Species_1\">0.0549</tr_salsVal>"
       << "<tr_salsVal species=\"Species_3\">0.0549</tr_salsVal>"
       << "</tr_saplingLinearSlope>"
       << "<tr_saplingLinearIntercept>"
       << "<tr_saliVal species=\"Species_1\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_2\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_3\">0</tr_saliVal>"
       << "</tr_saplingLinearIntercept>"
       << "<tr_seedlingLinearSlope>"
       << "<tr_selsVal species=\"Species_1\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_2\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_3\">122.86</tr_selsVal>"
       << "</tr_seedlingLinearSlope>"
       << "<tr_seedlingLinearIntercept>"
       << "<tr_seliVal species=\"Species_1\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_2\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_3\">-0.9</tr_seliVal>"
       << "</tr_seedlingLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">2</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">2</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">2</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultReverseLinearSlope>"
       << "<tr_arlsVal species=\"Species_1\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_2\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_3\">2.1</tr_arlsVal>"
       << "</tr_adultReverseLinearSlope>"
       << "<tr_adultReverseLinearIntercept>"
       << "<tr_arliVal species=\"Species_1\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_2\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_3\">0.02418</tr_arliVal>"
       << "</tr_adultReverseLinearIntercept>"
       << "<tr_saplingReverseLinearSlope>"
       << "<tr_sarlsVal species=\"Species_1\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_2\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_3\">1.1</tr_sarlsVal>"
       << "</tr_saplingReverseLinearSlope>"
       << "<tr_saplingReverseLinearIntercept>"
       << "<tr_sarliVal species=\"Species_1\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_2\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_3\">-0.847</tr_sarliVal>"
       << "</tr_saplingReverseLinearIntercept>"
       << "<tr_seedlingReverseLinearSlope>"
       << "<tr_serlsVal species=\"Species_2\">1.5</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_1\">0.761</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_3\">0.761</tr_serlsVal>"
       << "</tr_seedlingReverseLinearSlope>"
       << "<tr_seedlingReverseLinearIntercept>"
       << "<tr_serliVal species=\"Species_2\">0.02</tr_serliVal>"
       << "<tr_serliVal species=\"Species_1\">0.758</tr_serliVal>"
       << "<tr_serliVal species=\"Species_3\">0.758</tr_serliVal>"
       << "</tr_seedlingReverseLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">4</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">-1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">4</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">1</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">1</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">1</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultLinearSlope>"
       << "<tr_alsVal species=\"Species_1\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_2\">0</tr_alsVal>"
       << "<tr_alsVal species=\"Species_3\">1.3</tr_alsVal>"
       << "</tr_adultLinearSlope>"
       << "<tr_adultLinearIntercept>"
       << "<tr_aliVal species=\"Species_1\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_2\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_3\">0.9</tr_aliVal>"
       << "</tr_adultLinearIntercept>"
       << "<tr_saplingLinearSlope>"
       << "<tr_salsVal species=\"Species_2\">49.82</tr_salsVal>"
       << "<tr_salsVal species=\"Species_1\">0.0549</tr_salsVal>"
       << "<tr_salsVal species=\"Species_3\">0.0549</tr_salsVal>"
       << "</tr_saplingLinearSlope>"
       << "<tr_saplingLinearIntercept>"
       << "<tr_saliVal species=\"Species_1\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_2\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_3\">0</tr_saliVal>"
       << "</tr_saplingLinearIntercept>"
       << "<tr_seedlingLinearSlope>"
       << "<tr_selsVal species=\"Species_1\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_2\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_3\">122.86</tr_selsVal>"
       << "</tr_seedlingLinearSlope>"
       << "<tr_seedlingLinearIntercept>"
       << "<tr_seliVal species=\"Species_1\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_2\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_3\">-0.9</tr_seliVal>"
       << "</tr_seedlingLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile5()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">2</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">2</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">2</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultReverseLinearSlope>"
       << "<tr_arlsVal species=\"Species_1\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_2\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_3\">2.1</tr_arlsVal>"
       << "</tr_adultReverseLinearSlope>"
       << "<tr_adultReverseLinearIntercept>"
       << "<tr_arliVal species=\"Species_1\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_2\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_3\">0.02418</tr_arliVal>"
       << "</tr_adultReverseLinearIntercept>"
       << "<tr_saplingReverseLinearSlope>"
       << "<tr_sarlsVal species=\"Species_1\">0</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_2\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_3\">1.1</tr_sarlsVal>"
       << "</tr_saplingReverseLinearSlope>"
       << "<tr_saplingReverseLinearIntercept>"
       << "<tr_sarliVal species=\"Species_1\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_2\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_3\">-0.847</tr_sarliVal>"
       << "</tr_saplingReverseLinearIntercept>"
       << "<tr_seedlingReverseLinearSlope>"
       << "<tr_serlsVal species=\"Species_2\">1.5</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_1\">0.761</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_3\">0.761</tr_serlsVal>"
       << "</tr_seedlingReverseLinearSlope>"
       << "<tr_seedlingReverseLinearIntercept>"
       << "<tr_serliVal species=\"Species_2\">0.02</tr_serliVal>"
       << "<tr_serliVal species=\"Species_1\">0.758</tr_serliVal>"
       << "<tr_serliVal species=\"Species_3\">0.758</tr_serliVal>"
       << "</tr_seedlingReverseLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile6()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">1</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">1</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">1</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultLinearSlope>"
       << "<tr_alsVal species=\"Species_1\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_2\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_3\">1.3</tr_alsVal>"
       << "</tr_adultLinearSlope>"
       << "<tr_adultLinearIntercept>"
       << "<tr_aliVal species=\"Species_1\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_2\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_3\">0.9</tr_aliVal>"
       << "</tr_adultLinearIntercept>"
       << "<tr_saplingLinearSlope>"
       << "<tr_salsVal species=\"Species_2\">0</tr_salsVal>"
       << "<tr_salsVal species=\"Species_1\">0.0549</tr_salsVal>"
       << "<tr_salsVal species=\"Species_3\">0.0549</tr_salsVal>"
       << "</tr_saplingLinearSlope>"
       << "<tr_saplingLinearIntercept>"
       << "<tr_saliVal species=\"Species_1\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_2\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_3\">0</tr_saliVal>"
       << "</tr_saplingLinearIntercept>"
       << "<tr_seedlingLinearSlope>"
       << "<tr_selsVal species=\"Species_1\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_2\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_3\">122.86</tr_selsVal>"
       << "</tr_seedlingLinearSlope>"
       << "<tr_seedlingLinearIntercept>"
       << "<tr_seliVal species=\"Species_1\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_2\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_3\">-0.9</tr_seliVal>"
       << "</tr_seedlingLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile7()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">2</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">2</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">2</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultReverseLinearSlope>"
       << "<tr_arlsVal species=\"Species_1\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_2\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_3\">2.1</tr_arlsVal>"
       << "</tr_adultReverseLinearSlope>"
       << "<tr_adultReverseLinearIntercept>"
       << "<tr_arliVal species=\"Species_1\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_2\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_3\">0.02418</tr_arliVal>"
       << "</tr_adultReverseLinearIntercept>"
       << "<tr_saplingReverseLinearSlope>"
       << "<tr_sarlsVal species=\"Species_1\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_2\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_3\">0</tr_sarlsVal>"
       << "</tr_saplingReverseLinearSlope>"
       << "<tr_saplingReverseLinearIntercept>"
       << "<tr_sarliVal species=\"Species_1\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_2\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_3\">-0.847</tr_sarliVal>"
       << "</tr_saplingReverseLinearIntercept>"
       << "<tr_seedlingReverseLinearSlope>"
       << "<tr_serlsVal species=\"Species_2\">1.5</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_1\">0.761</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_3\">0.761</tr_serlsVal>"
       << "</tr_seedlingReverseLinearSlope>"
       << "<tr_seedlingReverseLinearIntercept>"
       << "<tr_serliVal species=\"Species_2\">0.02</tr_serliVal>"
       << "<tr_serliVal species=\"Species_1\">0.758</tr_serliVal>"
       << "<tr_serliVal species=\"Species_3\">0.758</tr_serliVal>"
       << "</tr_seedlingReverseLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile8()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">1</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">1</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">1</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">1</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">1</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">1</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultLinearSlope>"
       << "<tr_alsVal species=\"Species_1\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_2\">0.96</tr_alsVal>"
       << "<tr_alsVal species=\"Species_3\">1.3</tr_alsVal>"
       << "</tr_adultLinearSlope>"
       << "<tr_adultLinearIntercept>"
       << "<tr_aliVal species=\"Species_1\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_2\">0</tr_aliVal>"
       << "<tr_aliVal species=\"Species_3\">0.9</tr_aliVal>"
       << "</tr_adultLinearIntercept>"
       << "<tr_saplingLinearSlope>"
       << "<tr_salsVal species=\"Species_2\">49.82</tr_salsVal>"
       << "<tr_salsVal species=\"Species_1\">0.0549</tr_salsVal>"
       << "<tr_salsVal species=\"Species_3\">0.0549</tr_salsVal>"
       << "</tr_saplingLinearSlope>"
       << "<tr_saplingLinearIntercept>"
       << "<tr_saliVal species=\"Species_1\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_2\">1.2</tr_saliVal>"
       << "<tr_saliVal species=\"Species_3\">0</tr_saliVal>"
       << "</tr_saplingLinearIntercept>"
       << "<tr_seedlingLinearSlope>"
       << "<tr_selsVal species=\"Species_1\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_2\">96.29</tr_selsVal>"
       << "<tr_selsVal species=\"Species_3\">0</tr_selsVal>"
       << "</tr_seedlingLinearSlope>"
       << "<tr_seedlingLinearIntercept>"
       << "<tr_seliVal species=\"Species_1\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_2\">0</tr_seliVal>"
       << "<tr_seliVal species=\"Species_3\">-0.9</tr_seliVal>"
       << "</tr_seedlingLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile9()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile9()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">2</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">2</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">2</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">2</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">2</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">2</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_adultReverseLinearSlope>"
       << "<tr_arlsVal species=\"Species_1\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_2\">2.1</tr_arlsVal>"
       << "<tr_arlsVal species=\"Species_3\">2.1</tr_arlsVal>"
       << "</tr_adultReverseLinearSlope>"
       << "<tr_adultReverseLinearIntercept>"
       << "<tr_arliVal species=\"Species_1\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_2\">0.02418</tr_arliVal>"
       << "<tr_arliVal species=\"Species_3\">0.02418</tr_arliVal>"
       << "</tr_adultReverseLinearIntercept>"
       << "<tr_saplingReverseLinearSlope>"
       << "<tr_sarlsVal species=\"Species_1\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_2\">1.5</tr_sarlsVal>"
       << "<tr_sarlsVal species=\"Species_3\">1.1</tr_sarlsVal>"
       << "</tr_saplingReverseLinearSlope>"
       << "<tr_saplingReverseLinearIntercept>"
       << "<tr_sarliVal species=\"Species_1\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_2\">0.761</tr_sarliVal>"
       << "<tr_sarliVal species=\"Species_3\">-0.847</tr_sarliVal>"
       << "</tr_saplingReverseLinearIntercept>"
       << "<tr_seedlingReverseLinearSlope>"
       << "<tr_serlsVal species=\"Species_2\">0</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_1\">0.761</tr_serlsVal>"
       << "<tr_serlsVal species=\"Species_3\">0.761</tr_serlsVal>"
       << "</tr_seedlingReverseLinearSlope>"
       << "<tr_seedlingReverseLinearIntercept>"
       << "<tr_serliVal species=\"Species_2\">0.02</tr_serliVal>"
       << "<tr_serliVal species=\"Species_1\">0.758</tr_serliVal>"
       << "<tr_serliVal species=\"Species_3\">0.758</tr_serliVal>"
       << "</tr_seedlingReverseLinearIntercept>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile10()
/////////////////////////////////////////////////////////////////////////////
char * clTestAllometry::WriteXMLErrorFile10()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06040101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">45</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.02418</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">0.9</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.1</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.34</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">0.5</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">0.9</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.2871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
