//---------------------------------------------------------------------------
// TestDensitySeedSurvival.cpp
//---------------------------------------------------------------------------
#include "TestDensitySeedSurvival.h"
#include "SimManager.h"
#include "TreePopulation.h"
#include "GridBase.h"
#include <fstream.h>
#include <math.h>


/////////////////////////////////////////////////////////////////////////////
//  TestDensitySeedSurvival()
/////////////////////////////////////////////////////////////////////////////
void clTestDensitySeedSurvival::TestDensitySeedSurvival()
{

  clSimManager * p_oSimManager = new clSimManager(3, 3, "");
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clTree *p_oTree;
  clGridBase *p_oSeeds;
  float fValue, fX, fY, fXMin, fXMax, fYMin, fYMax;
  int *p_iNumSeedlings = new int[4], i;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile1());

  //Add the seeds to the appropriate grid cells
  p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
  fValue = 100;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 200;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 200;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Get the tree population
  p_oPop = (clTreePopulation*) p_oSimManager->GetPopulationObject("treepopulation");

  //Count the number of seedlings in each grid cell
  //Count the seedlings
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = 8;
  fXMin = 0 * 8;
  fXMax = (0 + 1) * 8;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(92 == p_iNumSeedlings[1] || 93 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(158 == p_iNumSeedlings[2] || 159 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(259 == p_iNumSeedlings[3] || 260 == p_iNumSeedlings[3]);

  //Check our values for cell 7, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 7 * 8;
  fXMax = (7 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(281 == p_iNumSeedlings[1] || 282 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(77 == p_iNumSeedlings[2] || 78 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(169 == p_iNumSeedlings[3] || 170 == p_iNumSeedlings[3]);

  //Check our values for cell 14, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 14 * 8;
  fXMax = (14 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(92 == p_iNumSeedlings[1] || 93 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(158 == p_iNumSeedlings[2] || 159 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(259 == p_iNumSeedlings[3] || 260 == p_iNumSeedlings[3]);

  //Check our values for cell 21, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 21 * 8;
  fXMax = (21 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(281 == p_iNumSeedlings[1] || 282 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(77 == p_iNumSeedlings[2] || 78 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(169 == p_iNumSeedlings[3] || 170 == p_iNumSeedlings[3]);

  //Check our values for cell 28, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 28 * 8;
  fXMax = (28 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(92 == p_iNumSeedlings[1] || 93 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(158 == p_iNumSeedlings[2] || 159 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(259 == p_iNumSeedlings[3] || 260 == p_iNumSeedlings[3]);

  //Check our values for cell 35, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 35 * 8;
  fXMax = (35 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(186 == p_iNumSeedlings[1] || 187 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(239 == p_iNumSeedlings[2] || 240 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(81 == p_iNumSeedlings[3] || 82 == p_iNumSeedlings[3]);

  //Check our values for cell 42, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 42 * 8;
  fXMax = (42 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(281 == p_iNumSeedlings[1] || 282 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(77 == p_iNumSeedlings[2] || 78 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(169 == p_iNumSeedlings[3] || 170 == p_iNumSeedlings[3]);

  //Check our values for cell 49, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 49 * 8;
  fXMax = (49 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(92 == p_iNumSeedlings[1] || 93 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(158 == p_iNumSeedlings[2] || 159 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(259 == p_iNumSeedlings[3] || 260 == p_iNumSeedlings[3]);

  //Check our values for cell 56, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 56 * 8;
  fXMax = (56 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(186 == p_iNumSeedlings[1] || 187 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(239 == p_iNumSeedlings[2] || 240 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(81 == p_iNumSeedlings[3] || 82 == p_iNumSeedlings[3]);

  //Check our values for cell 1, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 1 * 8;
  fXMax = (1 + 1) * 8;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[3]);

  delete[] p_iNumSeedlings;

  //Clean up
  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestDensitySeedSurvival::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>5</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>500.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.0242</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_4\">0.0242</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_4\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.464</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_4\">0.464</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_4\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.02871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Density Dependent Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_densDepSlope>"
       << "<es_ddsVal species=\"Species_2\">0.2</es_ddsVal>"
       << "<es_ddsVal species=\"Species_3\">0.4</es_ddsVal>"
       << "<es_ddsVal species=\"Species_4\">0.8</es_ddsVal>"
       << "</es_densDepSlope>"
       << "<es_densDepSteepness>"
       << "<es_ddstVal species=\"Species_2\">-0.2</es_ddstVal>"
       << "<es_ddstVal species=\"Species_3\">-0.1</es_ddstVal>"
       << "<es_ddstVal species=\"Species_4\">-0.3</es_ddstVal>"
       << "</es_densDepSteepness>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

