//---------------------------------------------------------------------------
// TestDensitySeedSurvival
//---------------------------------------------------------------------------
#if !defined(TestDensitySeedSurvival_H)
  #define TestDensitySeedSurvival_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clGridBase;
class clSimManager;

/**
* This class tests the density-dependent seed survival behavior.  It writes out
* parameter files and uses them as input to perform setup; it then sets up the
* desired initial conditions, causes the behavior to run, then tests its
* output.  There is one normal processing run.
*/
class clTestDensitySeedSurvival : public CppUnit::TestFixture
{

  public:

  /**
  * Tests normal processing of density-dependent seed survival.
  * WriteXMLFile1() does setup.  After a run occurs, the number of seeds in the
  * seed grid is verified.
  */
  void TestDensitySeedSurvival();

  private:

  /**
  * Writes a parameter file to direct testing.  The behaviors are non-spatial
  * disperse (designed to add no seeds) and density-dependent seed survival.
  * There are 4 species but only the last three are used.
  * @return Filename written.
  */
  char * WriteXMLFile1();
};
//---------------------------------------------------------------------------

#endif // TestDensitySeedSurvival_H
