//---------------------------------------------------------------------------
// TestDimensionAnalysis
//---------------------------------------------------------------------------
#if !defined(TestDimensionAnalysis_H)
  #define TestDimensionAnalysis_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;
class clTree;

/**
* Tests the class clDimensionAnalysis.
*/
class clTestDimensionAnalysis : public CppUnit::TestFixture {

  public:

  /**
  * Performs all the tests from one function.
  */
  void TestDimensionAnalysis();

  protected:

  /**
  * Tests normal processing.  This does runs 1 - 7.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessing(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  This uses WriteXMLErrorFileX() to introduce errors
  * and makes sure that they are caught.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Performs test run 1.  Tests equation 1, all possible units conversions.
  * WriteXMLFile1() does setup.  This function creates three trees for each
  * species, of varying sizes.  The run goes for a timestep and then the
  * function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun1(clSimManager *p_oSimManager);

  /**
  * Performs test run 2.  Tests equation 2, all possible units conversions.
  * WriteXMLFile2() does setup.  This function creates three trees for each
  * species, of varying sizes.  The run goes for a timestep and then the
  * function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun2(clSimManager *p_oSimManager);

  /**
  * Performs test run 3.  Tests equation 3, all possible units conversions.
  * WriteXMLFile3() does setup.  This function creates three trees for each
  * species, of varying sizes.  The run goes for a timestep and then the
  * function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun3(clSimManager *p_oSimManager);

  /**
  * Performs test run 4.  Tests equations 4 and 5, all possible units
  * conversions. WriteXMLFile4() does setup.  This function creates three trees
  * for each species, of varying sizes.  The run goes for a timestep and then
  * the function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun4(clSimManager *p_oSimManager);

  /**
  * Performs test run 5.  Tests equations 6 and 7, all possible units
  * conversions. WriteXMLFile5() does setup.  This function creates three trees
  * for each species, of varying sizes.  The run goes for a timestep and then
  * the function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun5(clSimManager *p_oSimManager);

  /**
  * Performs test run 6.  Tests equation 8, all possible units conversions.
  * WriteXMLFile6() does setup.  This function creates three trees for each
  * species, of varying sizes.  The run goes for a timestep and then the
  * function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun6(clSimManager *p_oSimManager);

  /**
  * Performs test run 7.  Tests equation 9, all possible units conversions.
  * WriteXMLFile7() does setup.  This function creates three trees for each
  * species, of varying sizes.  The run goes for a timestep and then the
  * function checks the biomass values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestRun7(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for run 1.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  All 18 used species use equation
  * 1.  The first 9 use a correction factor; the second 9 don't.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes the parameter file for run 2.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  All 18 used species use equation
  * 2.  The first 9 use a correction factor; the second 9 don't.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes the parameter file for run 3.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  All 18 used species use equation
  * 3.  The first 9 use a correction factor; the second 9 don't.
  * @return Filename written.
  */
  char* WriteXMLFile3();

  /**
  * Writes the parameter file for run 4.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  The first 9 species use equation
  * 4; the second 9 use equation 5.
  * @return Filename written.
  */
  char* WriteXMLFile4();

  /**
  * Writes the parameter file for run 5.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  The first 9 species use equation
  * 6; the second 9 use equation 7.
  * @return Filename written.
  */
  char* WriteXMLFile5();

  /**
  * Writes the parameter file for run 6.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  All 18 used species use equation
  * 8.  The first 9 use a correction factor; the second 9 don't.
  * @return Filename written.
  */
  char* WriteXMLFile6();

  /**
  * Writes the parameter file for run 7.  There are 19 species (Species 13 is
  * not used).  The biomass calculator is the only behavior and is applied to
  * saplings and adults of all used species.  All 18 used species use equation
  * 9.  The first 9 use a correction factor; the second 9 don't.
  * @return Filename written.
  */
  char* WriteXMLFile7();

  /**
  * Writes an error file where an equation ID is unrecognized.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where a DBH units value is unrecognized.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error file where the biomass calculator is applied to a seedling.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error file where a biomass units value is unrecognized.
  * @return Filename written.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes an error file where a correction factor flag value is unrecognized.
  * @return Filename written.
  */
  char* WriteXMLErrorFile5();

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * This ends with </behaviorList>.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * This ends with </behaviorList>.  There are only two species for this
  * file.
  * @param oOut File stream to write to.
  */
  void WriteCommonErrorStuff(std::fstream &oOut);

  /**
  * Creates the trees.  3 of each species are created (Species 1 to Species 19,
  * Species 13 excepted).  There is one of DBH 5 cm, one of DBH 50 cm, and
  * one of DBH 100 cm.  Pointers to the new trees are placed in the passed
  * array.
  * @param p_oPop Tree population object.
  * @return Array of created trees, 54 trees long.
  */
  clTree** CreateTrees(clTreePopulation *p_oPop);

};
//---------------------------------------------------------------------------
#endif // TestBiomassCalculator_H
