//---------------------------------------------------------------------------
#include "TestLightBehaviors.h"
#include <fstream.h>
#include <math.h>

#include "TreePopulation.h"
#include "TreeSearch.h"
#include "SimManager.h"
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestLight()
/////////////////////////////////////////////////////////////////////////////
void clTestLightBehaviors::TestLight() {

  clSimManager *p_oSimManager = new clSimManager(3, 3, "");

  TestGLICalculations(p_oSimManager);
  TestDoSetupErrorProcessing(p_oSimManager);

  //Clean up
   delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
//  TestGLICalculations()
/////////////////////////////////////////////////////////////////////////////
void clTestLightBehaviors::TestGLICalculations(clSimManager *p_oSimManager) {
  clTree *p_oTarget1, *p_oTarget2, *p_oTarget3, *p_oTarget4, *p_oTarget5, *p_oTarget6,
   *p_oTree;
  float fX, fY, fDiam, fLight, fExpectedLight;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile3());
  clPopulationBase *p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  clTreePopulation *p_oPop = (clTreePopulation*)p_oTemp;

  //Create our trees
  // # 1
  fX = 75;
  fY = 80;
  fDiam = 15;
  p_oTarget1 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 2
  fX = 50;
  fY = 50;
  fDiam = 11;
  p_oTarget2 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 3
  fX = 56.1;
  fY = 50;
  fDiam = 45;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 4
  fX = 190;
  fY = 193;
  fDiam = 4;
  p_oTarget3 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 5
  fX = 187;
  fY = 190;
  fDiam = 140;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 6
  fX = 10;
  fY = 185;
  fDiam = 40;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 7
  fX = 11;
  fY = 11;
  fDiam = 45;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 8
  fX = 10;
  fY = 10;
  fDiam = 15;
  p_oTarget4 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 9
  fX = 156;
  fY = 15;
  fDiam = 18;
  p_oTarget5 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 10
  fX = 155;
  fY = 21.5;
  fDiam = 56;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 11
  fX = 147;
  fY = 8;
  fDiam = 62;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 12
  fX = 147;
  fY = 17;
  fDiam = 57;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 13
  fX = 12;
  fY = 194;
  fDiam = 8;
  p_oTarget6 = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 14
  fX = 9;
  fY = 4;
  fDiam = 61;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 15
  fX = 1;
  fY = 199;
  fDiam = 41;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 16
  fX = 51;
  fY = 57;
  fDiam = 15;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  // # 17
  fX = 59;
  fY = 57;
  fDiam = 45;
  p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);

  //Dead neighbor
  fX = 51;
  fY = 51;
  fDiam = 50;
  p_oTree = p_oPop->CreateTree (fX, fY, 0, clTreePopulation::adult, fDiam);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), true);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Check the values
  p_oTarget1->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget1->GetSpecies(), p_oTarget1->GetType()), &fLight);
  fExpectedLight = 100;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);

  p_oTarget2->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget2->GetSpecies(), p_oTarget2->GetType()), &fLight);
  fExpectedLight = 90.4544612;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);

  p_oTarget3->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget3->GetSpecies(), p_oTarget3->GetType()), &fLight);
  fExpectedLight = 38.9158116;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);

  p_oTarget4->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget4->GetSpecies(), p_oTarget4->GetType()), &fLight);
  fExpectedLight = 13.68761304;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);

  p_oTarget5->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget5->GetSpecies(), p_oTarget5->GetType()), &fLight);
  fExpectedLight = 81.9849348;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);

  p_oTarget6->GetValue(p_oPop->GetFloatDataCode("Light", p_oTarget6->GetSpecies(), p_oTarget6->GetType()), &fLight);
  fExpectedLight = 79.96579752;
  CPPUNIT_ASSERT(fabs(fExpectedLight - fLight) < 0.1);
}

////////////////////////////////////////////////////////////////////////////
// TestDoSetupErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestLightBehaviors::TestDoSetupErrorProcessing(clSimManager *p_oSimManager) {

   //Feed our error file to the sim manager
   try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestLight error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clLightOrg::DoSetup") == NULL)
    {
      CppUnit::Asserter::fail("TestLights error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

}
//---------------------------------------------------------------------------
/*///////////////////////////////////////////////////////////////////////////
  WriteXMLFile2()
///////////////////////////////////////////////////////////////////////////*/
char* clTestLightBehaviors::WriteXMLFile2() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>5</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Western_Hemlock\" />"
       << "<tr_species speciesName=\"Western_Redcedar\" />"
       << "<tr_species speciesName=\"Amabilis_Fir\" />"
       << "<tr_species speciesName=\"Subalpine_Fir\" />"
       << "<tr_species speciesName=\"Hybrid_Spruce\" />"
       << "<tr_species speciesName=\"Lodgepole_Pine\" />"
       << "<tr_species speciesName=\"Trembling_Aspen\" />"
       << "<tr_species speciesName=\"Black_Cottonwood\" />"
       << "<tr_species speciesName=\"Paper_Birch\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Western_Hemlock\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Western_Redcedar\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Amabilis_Fir\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Subalpine_Fir\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Hybrid_Spruce\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Lodgepole_Pine\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Trembling_Aspen\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Black_Cottonwood\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Paper_Birch\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Western_Hemlock\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Western_Redcedar\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Amabilis_Fir\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Subalpine_Fir\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Hybrid_Spruce\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Lodgepole_Pine\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Trembling_Aspen\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Black_Cottonwood\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Paper_Birch\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Western_Hemlock\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Western_Redcedar\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Amabilis_Fir\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Subalpine_Fir\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Hybrid_Spruce\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Lodgepole_Pine\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Trembling_Aspen\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Black_Cottonwood\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Paper_Birch\" tp=\"1\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"Diam10\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Western_Hemlock\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Western_Redcedar\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Amabilis_Fir\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Subalpine_Fir\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Hybrid_Spruce\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Lodgepole_Pine\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Trembling_Aspen\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Black_Cottonwood\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Paper_Birch\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">4</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Western_Hemlock\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Western_Redcedar\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Amabilis_Fir\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Subalpine_Fir\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Hybrid_Spruce\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Lodgepole_Pine\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Trembling_Aspen\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Black_Cottonwood\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Paper_Birch\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">3</tm_floatCode>"
       << "</tm_floatCodes>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">7.53784</fl>"
       << "<fl c=\"1\">6.73828</fl>"
       << "<fl c=\"3\">42.287</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">12.615</fl>"
       << "<fl c=\"1\">7.39582</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">21.4159</fl>"
       << "<fl c=\"1\">7.66433</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.869</fl>"
       << "<fl c=\"1\">6.88451</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.154</fl>"
       << "<fl c=\"1\">3.28625</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.167</fl>"
       << "<fl c=\"1\">8.01098</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">194.711</fl>"
       << "<fl c=\"1\">9.149</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"1\">"
       << "<fl c=\"0\">197.015</fl>"
       << "<fl c=\"1\">7.33485</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">8.44727</fl>"
       << "<fl c=\"1\">19.0552</fl>"
       << "<fl c=\"3\">209.256</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">4.73022</fl>"
       << "<fl c=\"1\">14.209</fl>"
       << "<fl c=\"3\">179.455</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">7.86133</fl>"
       << "<fl c=\"1\">17.8833</fl>"
       << "<fl c=\"3\">32.3657</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"3\">"
       << "<fl c=\"0\">6.43311</fl>"
       << "<fl c=\"1\">11.8713</fl>"
       << "<fl c=\"3\">36.149</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">7.76978</fl>"
       << "<fl c=\"1\">14.6851</fl>"
       << "<fl c=\"3\">27.2324</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">17.4866</fl>"
       << "<fl c=\"1\">11.4075</fl>"
       << "<fl c=\"3\">218.842</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">183.355</fl>"
       << "<fl c=\"1\">17.7956</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.739</fl>"
       << "<fl c=\"1\">19.4068</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.949</fl>"
       << "<fl c=\"1\">19.0309</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"1\">"
       << "<fl c=\"0\">195.158</fl>"
       << "<fl c=\"1\">11.8037</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">6.2561</fl>"
       << "<fl c=\"1\">26.2634</fl>"
       << "<fl c=\"3\">198.038</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">8.3252</fl>"
       << "<fl c=\"1\">28.4912</fl>"
       << "<fl c=\"3\">120.764</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">4.15039</fl>"
       << "<fl c=\"1\">28.833</fl>"
       << "<fl c=\"3\">123.805</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">0.195312</fl>"
       << "<fl c=\"1\">29.2969</fl>"
       << "<fl c=\"3\">93.6911</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">1.27563</fl>"
       << "<fl c=\"1\">26.6296</fl>"
       << "<fl c=\"3\">102.979</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">3.54614</fl>"
       << "<fl c=\"1\">20.8191</fl>"
       << "<fl c=\"3\">83.1708</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">9.00269</fl>"
       << "<fl c=\"1\">28.241</fl>"
       << "<fl c=\"3\">66.2924</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">11.0046</fl>"
       << "<fl c=\"1\">21.8872</fl>"
       << "<fl c=\"3\">111.81</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">13.3423</fl>"
       << "<fl c=\"1\">20.2087</fl>"
       << "<fl c=\"3\">48.0237</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">27.9993</fl>"
       << "<fl c=\"1\">29.4419</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"1\">"
       << "<fl c=\"0\">28.0252</fl>"
       << "<fl c=\"1\">20.1676</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.155</fl>"
       << "<fl c=\"1\">26.9176</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.24</fl>"
       << "<fl c=\"1\">29.8826</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.756</fl>"
       << "<fl c=\"1\">27.9779</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"1\">"
       << "<fl c=\"0\">197.32</fl>"
       << "<fl c=\"1\">21.1579</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1.83716</fl>"
       << "<fl c=\"1\">39.9292</fl>"
       << "<fl c=\"3\">48.0389</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">6.7627</fl>"
       << "<fl c=\"1\">34.9731</fl>"
       << "<fl c=\"3\">33.0643</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"2\">"
       << "<fl c=\"0\">0.65918</fl>"
       << "<fl c=\"1\">37.0911</fl>"
       << "<fl c=\"4\">5.73792</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">19.8669</fl>"
       << "<fl c=\"1\">39.5752</fl>"
       << "<fl c=\"3\">149.809</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">15.6677</fl>"
       << "<fl c=\"1\">32.6355</fl>"
       << "<fl c=\"3\">124.539</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"1\">"
       << "<fl c=\"0\">186.253</fl>"
       << "<fl c=\"1\">35.7011</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.19</fl>"
       << "<fl c=\"1\">36.5094</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.24</fl>"
       << "<fl c=\"1\">30.2267</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.043</fl>"
       << "<fl c=\"1\">34.9439</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.242</fl>"
       << "<fl c=\"1\">36.9371</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1.17798</fl>"
       << "<fl c=\"1\">47.6868</fl>"
       << "<fl c=\"3\">142.194</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">9.88159</fl>"
       << "<fl c=\"1\">47.2046</fl>"
       << "<fl c=\"3\">98.338</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">15.2344</fl>"
       << "<fl c=\"1\">41.9983</fl>"
       << "<fl c=\"3\">87.98</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">27.9938</fl>"
       << "<fl c=\"1\">47.946</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">27.97</fl>"
       << "<fl c=\"1\">44.3605</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.006</fl>"
       << "<fl c=\"1\">44.4426</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.172</fl>"
       << "<fl c=\"1\">45.4414</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">199.678</fl>"
       << "<fl c=\"1\">40.0708</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">7.48901</fl>"
       << "<fl c=\"1\">53.0701</fl>"
       << "<fl c=\"3\">138.253</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">6.23779</fl>"
       << "<fl c=\"1\">55.9875</fl>"
       << "<fl c=\"3\">31.7838</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">15.6616</fl>"
       << "<fl c=\"1\">55.3528</fl>"
       << "<fl c=\"3\">177.568</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.299</fl>"
       << "<fl c=\"1\">56.0482</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.036</fl>"
       << "<fl c=\"1\">53.9111</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.733</fl>"
       << "<fl c=\"1\">52.8806</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.946</fl>"
       << "<fl c=\"1\">50.2555</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">5.88989</fl>"
       << "<fl c=\"1\">63.1897</fl>"
       << "<fl c=\"3\">118.114</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">0.701904</fl>"
       << "<fl c=\"1\">60.9924</fl>"
       << "<fl c=\"3\">118.797</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"2\">"
       << "<fl c=\"0\">5.23071</fl>"
       << "<fl c=\"1\">60.1624</fl>"
       << "<fl c=\"4\">1.67274</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">10.2783</fl>"
       << "<fl c=\"1\">68.0176</fl>"
       << "<fl c=\"3\">178.899</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">8.30078</fl>"
       << "<fl c=\"1\">78.9124</fl>"
       << "<fl c=\"3\">214.041</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">9.0332</fl>"
       << "<fl c=\"1\">75.1099</fl>"
       << "<fl c=\"3\">140.878</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">1.49536</fl>"
       << "<fl c=\"1\">78.2104</fl>"
       << "<fl c=\"3\">108.101</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">7.4585</fl>"
       << "<fl c=\"1\">72.821</fl>"
       << "<fl c=\"3\">50.7718</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">19.0979</fl>"
       << "<fl c=\"1\">74.3164</fl>"
       << "<fl c=\"3\">131.227</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">16.6138</fl>"
       << "<fl c=\"1\">72.0825</fl>"
       << "<fl c=\"3\">142.415</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">19.5007</fl>"
       << "<fl c=\"1\">76.9409</fl>"
       << "<fl c=\"3\">104.453</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">19.751</fl>"
       << "<fl c=\"1\">78.1067</fl>"
       << "<fl c=\"3\">15.8</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">16.4307</fl>"
       << "<fl c=\"1\">72.7112</fl>"
       << "<fl c=\"3\">13.9148</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"2\">"
       << "<fl c=\"0\">11.3281</fl>"
       << "<fl c=\"1\">76.7334</fl>"
       << "<fl c=\"4\">3.27362</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">1.70288</fl>"
       << "<fl c=\"1\">88.2141</fl>"
       << "<fl c=\"3\">126.979</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">0.439453</fl>"
       << "<fl c=\"1\">83.9844</fl>"
       << "<fl c=\"3\">38.9539</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">13.8</fl>"
       << "<fl c=\"1\">86.4746</fl>"
       << "<fl c=\"3\">187.616</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">16.9617</fl>"
       << "<fl c=\"1\">87.3474</fl>"
       << "<fl c=\"3\">76.4243</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">19.7083</fl>"
       << "<fl c=\"1\">84.1492</fl>"
       << "<fl c=\"3\">84.313</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">13.7695</fl>"
       << "<fl c=\"1\">81.8298</fl>"
       << "<fl c=\"3\">83.3414</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">11.6516</fl>"
       << "<fl c=\"1\">95.99</fl>"
       << "<fl c=\"3\">151.246</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">16.5344</fl>"
       << "<fl c=\"1\">90.3503</fl>"
       << "<fl c=\"3\">86.9724</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">19.7693</fl>"
       << "<fl c=\"1\">92.2729</fl>"
       << "<fl c=\"3\">42.8711</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"2\">"
       << "<fl c=\"0\">16.2358</fl>"
       << "<fl c=\"1\">92.0532</fl>"
       << "<fl c=\"4\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"2\">"
       << "<fl c=\"0\">195.201</fl>"
       << "<fl c=\"1\">98.7501</fl>"
       << "<fl c=\"4\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">0.701904</fl>"
       << "<fl c=\"1\">109.729</fl>"
       << "<fl c=\"3\">211.016</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"3\">"
       << "<fl c=\"0\">4.90112</fl>"
       << "<fl c=\"1\">105.585</fl>"
       << "<fl c=\"3\">10.5368</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"2\">"
       << "<fl c=\"0\">8.23364</fl>"
       << "<fl c=\"1\">109.29</fl>"
       << "<fl c=\"4\">6.59088</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">13.501</fl>"
       << "<fl c=\"1\">109.753</fl>"
       << "<fl c=\"3\">229.351</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"2\">"
       << "<fl c=\"0\">196.106</fl>"
       << "<fl c=\"1\">108.482</fl>"
       << "<fl c=\"4\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">3.35083</fl>"
       << "<fl c=\"1\">110.382</fl>"
       << "<fl c=\"3\">151.434</fl>"
       << "</tree>"
       << "<tree sp=\"4\" tp=\"3\">"
       << "<fl c=\"0\">6.79321</fl>"
       << "<fl c=\"1\">112.616</fl>"
       << "<fl c=\"3\">27.6627</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">16.3513</fl>"
       << "<fl c=\"1\">117.035</fl>"
       << "<fl c=\"3\">65.1047</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">0.805664</fl>"
       << "<fl c=\"1\">125.818</fl>"
       << "<fl c=\"3\">116.302</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">3.54004</fl>"
       << "<fl c=\"1\">129.065</fl>"
       << "<fl c=\"3\">57.2803</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"2\">"
       << "<fl c=\"0\">8.36182</fl>"
       << "<fl c=\"1\">125.342</fl>"
       << "<fl c=\"4\">4.19113</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">14.0076</fl>"
       << "<fl c=\"1\">126.416</fl>"
       << "<fl c=\"3\">149.015</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">13.1714</fl>"
       << "<fl c=\"1\">127.411</fl>"
       << "<fl c=\"3\">93.1204</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">19.635</fl>"
       << "<fl c=\"1\">120.782</fl>"
       << "<fl c=\"3\">64.0005</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">17.8589</fl>"
       << "<fl c=\"1\">123.34</fl>"
       << "<fl c=\"3\">19.5918</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"2\">"
       << "<fl c=\"0\">13.6841</fl>"
       << "<fl c=\"1\">124.811</fl>"
       << "<fl c=\"4\">3.27698</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"1\">"
       << "<fl c=\"0\">27.9377</fl>"
       << "<fl c=\"1\">122.748</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"1\">"
       << "<fl c=\"0\">23.262</fl>"
       << "<fl c=\"1\">124.983</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">194.679</fl>"
       << "<fl c=\"1\">128.887</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.019</fl>"
       << "<fl c=\"1\">125.823</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.291</fl>"
       << "<fl c=\"1\">128.959</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">8.29693</fl>"
       << "<fl c=\"1\">134.838</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">7.43688</fl>"
       << "<fl c=\"1\">135.838</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"3\">"
       << "<fl c=\"0\">17.2913</fl>"
       << "<fl c=\"1\">131.659</fl>"
       << "<fl c=\"3\">216.645</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">19.1711</fl>"
       << "<fl c=\"1\">130.658</fl>"
       << "<fl c=\"3\">154.753</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"3\">"
       << "<fl c=\"0\">12.9944</fl>"
       << "<fl c=\"1\">134.595</fl>"
       << "<fl c=\"3\">182.088</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"2\">"
       << "<fl c=\"0\">11.2305</fl>"
       << "<fl c=\"1\">130.31</fl>"
       << "<fl c=\"4\">8.75076</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"1\">"
       << "<fl c=\"0\">14.2561</fl>"
       << "<fl c=\"1\">139.276</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">28.1708</fl>"
       << "<fl c=\"1\">137.51</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.216</fl>"
       << "<fl c=\"1\">134.534</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">5.29175</fl>"
       << "<fl c=\"1\">144.012</fl>"
       << "<fl c=\"3\">188.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">9.45435</fl>"
       << "<fl c=\"1\">142.896</fl>"
       << "<fl c=\"3\">169.034</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">9.23462</fl>"
       << "<fl c=\"1\">144.617</fl>"
       << "<fl c=\"3\">171.924</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">4.94162</fl>"
       << "<fl c=\"1\">149.105</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">1.2705</fl>"
       << "<fl c=\"1\">144.72</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">6.03397</fl>"
       << "<fl c=\"1\">143.939</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">14.502</fl>"
       << "<fl c=\"1\">148.645</fl>"
       << "<fl c=\"3\">198.213</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">16.7786</fl>"
       << "<fl c=\"1\">148.969</fl>"
       << "<fl c=\"3\">163.683</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">19.8242</fl>"
       << "<fl c=\"1\">147.675</fl>"
       << "<fl c=\"3\">29.9881</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">28.0728</fl>"
       << "<fl c=\"1\">149.134</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">26.1565</fl>"
       << "<fl c=\"1\">141.844</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"1\">"
       << "<fl c=\"0\">197.261</fl>"
       << "<fl c=\"1\">141.75</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">194.706</fl>"
       << "<fl c=\"1\">146.153</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.912</fl>"
       << "<fl c=\"1\">147.692</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.11</fl>"
       << "<fl c=\"1\">145.798</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.067</fl>"
       << "<fl c=\"1\">149.294</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.214</fl>"
       << "<fl c=\"1\">149.371</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"1\">"
       << "<fl c=\"0\">199.36</fl>"
       << "<fl c=\"1\">141.669</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.115</fl>"
       << "<fl c=\"1\">144.137</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">3.32642</fl>"
       << "<fl c=\"1\">157.123</fl>"
       << "<fl c=\"3\">131.533</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">2.19116</fl>"
       << "<fl c=\"1\">155.09</fl>"
       << "<fl c=\"3\">58.8745</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">1.66626</fl>"
       << "<fl c=\"1\">150.751</fl>"
       << "<fl c=\"3\">61.1917</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">19.7021</fl>"
       << "<fl c=\"1\">155.963</fl>"
       << "<fl c=\"3\">218.076</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">11.6394</fl>"
       << "<fl c=\"1\">158.215</fl>"
       << "<fl c=\"3\">204.495</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">19.104</fl>"
       << "<fl c=\"1\">159.656</fl>"
       << "<fl c=\"3\">33.7991</fl>"
       << "</tree>"
       << "<tree sp=\"6\" tp=\"3\">"
       << "<fl c=\"0\">10.8521</fl>"
       << "<fl c=\"1\">155.267</fl>"
       << "<fl c=\"3\">25.4385</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"2\">"
       << "<fl c=\"0\">15.3625</fl>"
       << "<fl c=\"1\">155.2</fl>"
       << "<fl c=\"4\">8.4906</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">37.6551</fl>"
       << "<fl c=\"1\">154.914</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.18</fl>"
       << "<fl c=\"1\">150.994</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.3</fl>"
       << "<fl c=\"1\">157.788</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.142</fl>"
       << "<fl c=\"1\">154.44</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.245</fl>"
       << "<fl c=\"1\">154.003</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.107</fl>"
       << "<fl c=\"1\">152.696</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.295</fl>"
       << "<fl c=\"1\">152.198</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">0.305176</fl>"
       << "<fl c=\"1\">168.542</fl>"
       << "<fl c=\"3\">179.503</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">9.91211</fl>"
       << "<fl c=\"1\">167.072</fl>"
       << "<fl c=\"3\">27.0035</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">18.6707</fl>"
       << "<fl c=\"1\">160.162</fl>"
       << "<fl c=\"3\">105.906</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"2\">"
       << "<fl c=\"0\">17.7185</fl>"
       << "<fl c=\"1\">166.144</fl>"
       << "<fl c=\"4\">1.64398</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">28.0768</fl>"
       << "<fl c=\"1\">165.5</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"3\">"
       << "<fl c=\"0\">6.79932</fl>"
       << "<fl c=\"1\">178.748</fl>"
       << "<fl c=\"3\">186.345</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">9.65576</fl>"
       << "<fl c=\"1\">177.496</fl>"
       << "<fl c=\"3\">129.785</fl>"
       << "</tree>"
       << "<tree sp=\"7\" tp=\"1\">"
       << "<fl c=\"0\">196.27</fl>"
       << "<fl c=\"1\">179.152</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"8\" tp=\"2\">"
       << "<fl c=\"0\">6.22559</fl>"
       << "<fl c=\"1\">187.61</fl>"
       << "<fl c=\"4\">4.33754</fl>"
       << "</tree>"
       << "<tree sp=\"3\" tp=\"2\">"
       << "<fl c=\"0\">2.0752</fl>"
       << "<fl c=\"1\">187.39</fl>"
       << "<fl c=\"4\">0.911407</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.099</fl>"
       << "<fl c=\"1\">181.469</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"1\">"
       << "<fl c=\"0\">197.376</fl>"
       << "<fl c=\"1\">189.409</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">8.26416</fl>"
       << "<fl c=\"1\">198.065</fl>"
       << "<fl c=\"3\">184.359</fl>"
       << "</tree>"
       << "<tree sp=\"5\" tp=\"3\">"
       << "<fl c=\"0\">9.81445</fl>"
       << "<fl c=\"1\">199.64</fl>"
       << "<fl c=\"3\">145.673</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">2.81982</fl>"
       << "<fl c=\"1\">199.384</fl>"
       << "<fl c=\"3\">162.327</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">4.19922</fl>"
       << "<fl c=\"1\">198.761</fl>"
       << "<fl c=\"3\">148.72</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">6.46362</fl>"
       << "<fl c=\"1\">190.222</fl>"
       << "<fl c=\"3\">70.9824</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">8.64258</fl>"
       << "<fl c=\"1\">190.143</fl>"
       << "<fl c=\"3\">36.5808</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.926</fl>"
       << "<fl c=\"1\">199.127</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">196.197</fl>"
       << "<fl c=\"1\">194.685</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">195.847</fl>"
       << "<fl c=\"1\">195.283</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.328</fl>"
       << "<fl c=\"1\">197.156</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"1\">"
       << "<fl c=\"0\">197.288</fl>"
       << "<fl c=\"1\">199.241</fl>"
       << "<fl c=\"3\">0.2</fl>"
       << "</tree>"
       << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Western_Hemlock\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Western_Redcedar\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Amabilis_Fir\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Subalpine_Fir\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Hybrid_Spruce\">45.0</tr_chVal>"
       << "<tr_chVal species=\"Lodgepole_Pine\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Trembling_Aspen\">39.14</tr_chVal>"
       << "<tr_chVal species=\"Black_Cottonwood\">39.47</tr_chVal>"
       << "<tr_chVal species=\"Paper_Birch\">33.18</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Western_Hemlock\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Western_Redcedar\">0.0614</tr_crtdVal>"
       << "<tr_crtdVal species=\"Amabilis_Fir\">0.0242</tr_crtdVal>"
       << "<tr_crtdVal species=\"Subalpine_Fir\">0.0251</tr_crtdVal>"
       << "<tr_crtdVal species=\"Hybrid_Spruce\">0.0239</tr_crtdVal>"
       << "<tr_crtdVal species=\"Lodgepole_Pine\">0.0303</tr_crtdVal>"
       << "<tr_crtdVal species=\"Trembling_Aspen\">0.0328</tr_crtdVal>"
       << "<tr_crtdVal species=\"Black_Cottonwood\">0.0247</tr_crtdVal>"
       << "<tr_crtdVal species=\"Paper_Birch\">0.0484</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Western_Hemlock\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Western_Redcedar\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Amabilis_Fir\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Subalpine_Fir\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Hybrid_Spruce\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Lodgepole_Pine\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Trembling_Aspen\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Black_Cottonwood\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Paper_Birch\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Western_Hemlock\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Western_Redcedar\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Amabilis_Fir\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Subalpine_Fir\">0.7776</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Hybrid_Spruce\">0.6933</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Lodgepole_Pine\">0.8014</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Trembling_Aspen\">0.7992</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Black_Cottonwood\">0.7926</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Paper_Birch\">0.7803</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Western_Hemlock\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Western_Redcedar\">0.368</tr_fohicVal>"
       << "<tr_fohicVal species=\"Amabilis_Fir\">0.464</tr_fohicVal>"
       << "<tr_fohicVal species=\"Subalpine_Fir\">0.454</tr_fohicVal>"
       << "<tr_fohicVal species=\"Hybrid_Spruce\">0.405</tr_fohicVal>"
       << "<tr_fohicVal species=\"Lodgepole_Pine\">0.201</tr_fohicVal>"
       << "<tr_fohicVal species=\"Trembling_Aspen\">0.301</tr_fohicVal>"
       << "<tr_fohicVal species=\"Black_Cottonwood\">0.42</tr_fohicVal>"
       << "<tr_fohicVal species=\"Paper_Birch\">0.315</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Western_Hemlock\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Western_Redcedar\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Amabilis_Fir\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Subalpine_Fir\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Hybrid_Spruce\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Lodgepole_Pine\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Trembling_Aspen\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Black_Cottonwood\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Paper_Birch\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Western_Hemlock\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Western_Redcedar\">0.0269</tr_sohdVal>"
       << "<tr_sohdVal species=\"Amabilis_Fir\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Subalpine_Fir\">0.02815</tr_sohdVal>"
       << "<tr_sohdVal species=\"Hybrid_Spruce\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Lodgepole_Pine\">0.03224</tr_sohdVal>"
       << "<tr_sohdVal species=\"Trembling_Aspen\">0.04796</tr_sohdVal>"
       << "<tr_sohdVal species=\"Black_Cottonwood\">0.04681</tr_sohdVal>"
       << "<tr_sohdVal species=\"Paper_Birch\">0.04101</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Western_Hemlock\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Western_Redcedar\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Amabilis_Fir\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Subalpine_Fir\">0.0264</tr_soahVal>"
       << "<tr_soahVal species=\"Hybrid_Spruce\">0.0264</tr_soahVal>"
       << "<tr_soahVal species=\"Lodgepole_Pine\">0.0333</tr_soahVal>"
       << "<tr_soahVal species=\"Trembling_Aspen\">0.0352</tr_soahVal>"
       << "<tr_soahVal species=\"Black_Cottonwood\">0.0347</tr_soahVal>"
       << "<tr_soahVal species=\"Paper_Birch\">0.0454</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Western_Hemlock\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Western_Redcedar\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Amabilis_Fir\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Subalpine_Fir\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Hybrid_Spruce\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Lodgepole_Pine\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Trembling_Aspen\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Black_Cottonwood\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Paper_Birch\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Western_Hemlock\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Western_Redcedar\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Amabilis_Fir\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Subalpine_Fir\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Hybrid_Spruce\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Lodgepole_Pine\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Trembling_Aspen\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Black_Cottonwood\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Paper_Birch\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Western_Hemlock\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Western_Redcedar\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Amabilis_Fir\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Subalpine_Fir\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Hybrid_Spruce\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Lodgepole_Pine\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Trembling_Aspen\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Black_Cottonwood\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Paper_Birch\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>quadratlight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Western_Hemlock\" type=\"Seedling\"/>"
       << "<applyTo species=\"Western_Redcedar\" type=\"Seedling\"/>"
       << "<applyTo species=\"Amabilis_Fir\" type=\"Seedling\"/>"
       << "<applyTo species=\"Subalpine_Fir\" type=\"Seedling\"/>"
       << "<applyTo species=\"Hybrid_Spruce\" type=\"Seedling\"/>"
       << "<applyTo species=\"Lodgepole_Pine\" type=\"Seedling\"/>"
       << "<applyTo species=\"Trembling_Aspen\" type=\"Seedling\"/>"
       << "<applyTo species=\"Black_Cottonwood\" type=\"Seedling\"/>"
       << "<applyTo species=\"Paper_Birch\" type=\"Seedling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>glilight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Western_Hemlock\" type=\"Sapling\"/>"
       << "<applyTo species=\"Western_Redcedar\" type=\"Sapling\"/>"
       << "<applyTo species=\"Amabilis_Fir\" type=\"Sapling\"/>"
       << "<applyTo species=\"Subalpine_Fir\" type=\"Sapling\"/>"
       << "<applyTo species=\"Hybrid_Spruce\" type=\"Sapling\"/>"
       << "<applyTo species=\"Lodgepole_Pine\" type=\"Sapling\"/>"
       << "<applyTo species=\"Trembling_Aspen\" type=\"Sapling\"/>"
       << "<applyTo species=\"Black_Cottonwood\" type=\"Sapling\"/>"
       << "<applyTo species=\"Paper_Birch\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>saillight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Western_Hemlock\" type=\"Adult\"/>"
       << "<applyTo species=\"Western_Redcedar\" type=\"Adult\"/>"
       << "<applyTo species=\"Amabilis_Fir\" type=\"Adult\"/>"
       << "<applyTo species=\"Subalpine_Fir\" type=\"Adult\"/>"
       << "<applyTo species=\"Hybrid_Spruce\" type=\"Adult\"/>"
       << "<applyTo species=\"Lodgepole_Pine\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Trembling_Aspen\" type=\"Adult\"/>"
       << "<applyTo species=\"Black_Cottonwood\" type=\"Adult\"/>"
       << "<applyTo species=\"Paper_Birch\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<gliLight>"
       << "<li_heightOfFishEyePhoto>0</li_heightOfFishEyePhoto>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Western_Hemlock\">0.08</li_lecVal>"
       << "<li_lecVal species=\"Western_Redcedar\">0.091</li_lecVal>"
       << "<li_lecVal species=\"Amabilis_Fir\">0.059</li_lecVal>"
       << "<li_lecVal species=\"Subalpine_Fir\">0.092</li_lecVal>"
       << "<li_lecVal species=\"Hybrid_Spruce\">0.114</li_lecVal>"
       << "<li_lecVal species=\"Lodgepole_Pine\">0.135</li_lecVal>"
       << "<li_lecVal species=\"Trembling_Aspen\">0.206</li_lecVal>"
       << "<li_lecVal species=\"Black_Cottonwood\">0.143</li_lecVal>"
       << "<li_lecVal species=\"Paper_Birch\">0.058</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "</gliLight>"
       << "<sailLight>"
       << "<li_maxShadingRadius>15.0</li_maxShadingRadius>"
       << "<li_skyMaskAngle>30.0</li_skyMaskAngle>"
       << "<li_crownFracOfHeight>0</li_crownFracOfHeight>"
       << "</sailLight>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestLightBehaviors::WriteXMLFile3() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.589</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>glilight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<gliLight>"
       << "<li_heightOfFishEyePhoto>1</li_heightOfFishEyePhoto>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "</gliLight>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/*///////////////////////////////////////////////////////////////////////////
  WriteXMLErrorFile1()
///////////////////////////////////////////////////////////////////////////*/
char* clTestLightBehaviors::WriteXMLErrorFile1() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>0.5</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.589</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>glilight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<gliLight>"
       << "<li_heightOfFishEyePhoto>1</li_heightOfFishEyePhoto>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "</gliLight>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------


