//---------------------------------------------------------------------------

#ifndef TestLightBehaviorsH
#define TestLightBehaviorsH

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

class clTreePopulation;
class clSimManager;

/**
  This class tests the light behaviors.
*/
class clTestLightBehaviors : public CppUnit::TestFixture {

public:

  /**
  * Puts the tests together into one.
  */
  void TestLight();

  private:

  /**For testing the values in tree records*/
  struct fakeRecord {
    float fX, /**<X value*/
          fY, /**<Y value*/
          fLight; /**<Expected GLI*/
    bool bRead; /**<whether or not this has been read*/
    };

  /**
  * Tests GLI calculations.  WriteXMLFile3() is used for setup.  Seventeen
  * trees are created, and the GLI calculations of six of them are tested to
  * make sure they are right.  There is only one species, for simplicity.
  * @param p_oSimManager Object to run a test with.
  */
  void TestGLICalculations(clSimManager *p_oSimManager);

  /**
  * This tests error processing during setup.  The only error currently trapped
  * for is that the number of years per timestep is less than 1.
  * @param p_oSimManager Object to run a test with.
  */
  void TestDoSetupErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file to direct testing.  The only difference between
  * this file and the one in WriteXMLFile1 is that it has a different number
  * of years per timestep; this makes sure that that makes no difference to
  * light.
  *
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes a parameter file to direct testing for GLI light assignments.
  *
  * @return Filename written.
  */
  char* WriteXMLFile3();

  /**
  * Writes a parameter file with a deliberate error.  The number of years per
  * timestep is less than 1, which should cause light to throw an error.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();
};
//---------------------------------------------------------------------------
#endif
