//---------------------------------------------------------------------------
// TestLinearBiLevelGrowth
//---------------------------------------------------------------------------
#if !defined(TestLinearBiLevelGrowth_H)
  #define TestLinearBiLevelGrowth_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clLinearBiLevelGrowth class.
*/
class clTestLinearBiLevelGrowth : public CppUnit::TestFixture {

  public:

  /**
  * Combines the testing into one behavior.
  */
  void TestLinearBiLevelGrowth();

  protected:

  /**
  * Tests normal processing run 1.  WriteXMLFile1() does setup.  Timestep
  * length is 1 year and there is a light grid present.  The growth used is
  * diam with auto height.  27 trees are created of 3 species and assigned to a
  * mix of light levels.  Then growth is run.  Their diameters and heights are
  * checked to make sure they are correct.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests normal processing run 2.  WriteXMLFile2() does setup.  Timestep
  * length is 3 years and there is a light grid present.  The growth used is
  * diam with auto height.  27 trees are created of 3 species and assigned to a
  * mix of light levels.  Then growth is run.  Their diameters and heights are
  * checked to make sure they are correct.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Tests normal processing run 3.  WriteXMLFile3() does setup.  Timestep
  * length is 1 year and there is a light grid present.  The growth used is
  * diam only.  27 trees are created of 3 species and assigned to a mix of
  * light levels.  Then growth is run.  Their diameters and heights are checked
  * to make sure they are correct.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun3(clSimManager *p_oSimManager);

  /**
  * Tests normal processing run 4.  WriteXMLFile4() does setup.  Timestep
  * length is 1 year and there is no light grid present.  The growth used is
  * diam with auto height.  27 trees are created of 3 species.  Then growth is
  * run.  Their diameters and heights are checked to make sure they are
  * correct.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun4(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  Inputs error files to make sure the errors are
  * caught.
  */
  void ErrorProcessing(clSimManager *p_oSimManager);


  /**
  * Writes a parameter file for normal processing run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a parameter file for normal processing run 2.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes a parameter file for normal processing run 3.
  * @return Filename written.
  */
  char* WriteXMLFile3();

  /**
  * Writes a parameter file for normal processing run 4.
  * @return Filename written.
  */
  char* WriteXMLFile4();

  /**
  * Writes a parameter file where a value for high-light growth threshold is
  * not between 0 and 100.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes common portions of the test parameter files.  This starts with
  * <randomSeed> and ends with </allometry>.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes growth parameters for the test parameter files.
  * @param oOut File stream to write to.
  */
  void WriteGrowthParameters(std::fstream &oOut);


};
//---------------------------------------------------------------------------
#endif // TestSimpleLinearGrowth_H
