//---------------------------------------------------------------------------
// TestSelectionHarvest
//---------------------------------------------------------------------------
#if !defined(TestSelectionHarvest_H)
  #define TestSelectionHarvest_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

class clSimManager;
class clTreePopulation;

/**
* Tests the clSelectionHarvest class.
*/
class clTestSelectionHarvest : public CppUnit::TestFixture
{
  public:

  /**
  * Groups together all the other harvest testing functions into a comprehensive
  * harvest test.
  */
  void TestSelectionHarvest();

  protected:

  struct tree{float fX, fY;
              int iSpecies;
              bool bDead, //whether the tree should be dead
              bFound;  //whether it was found in the tree population
              };


  /**
  * Performs the first harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0 - 100	          1	 AbsBA	        6             Whole plot
  * The harvest will be performed.  Then the remaining trees are checked to make
  * sure the proper ones were left alone.
  */
  void DoSelectionHarvestRun1(clSimManager *p_oSimManager);

/**
 * Performs the second harvest run.  This run has the following characteristics:
 * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
 * 1	        1	        0 - 100	          1	 AbsBA	        6.0             Whole plot
 * The harvest will be performed.  Then the remaining trees are checked to make
 * sure the proper ones were left alone.
 */

  void DoSelectionHarvestRun2(clSimManager *p_oSimManager);

/**
  * Performs the third harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0 - 100	          1	 AbsBA	        -5             Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

  void DoSelectionHarvestRun3(clSimManager *p_oSimManager);

/**
  * Performs the fourth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0-100	          1	 AbsBA	        500             Whole plot
  * The harvest will not be performed.  The run will continue.
  */

  void DoSelectionHarvestRun4(clSimManager *p_oSimManager);

/**
  * Performs the fifth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0-100     	   1	 AbsBA	                      Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

  void DoSelectionHarvestRun5(clSimManager *p_oSimManager);

/**
  * Performs the sixth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0-100   	   1	 AbsBA	        "bad"           Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

  void DoSelectionHarvestRun6(clSimManager *p_oSimManager);

/**
  * Performs the seventh harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0-20, 15-40	   1	 AbsBA	       6 , 6             Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

    void DoSelectionHarvestRun7(clSimManager *p_oSimManager);

/**
  * Performs the eigth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        0-20, 40-21	   1	 AbsBA	        6, 6             Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

    void DoSelectionHarvestRun8(clSimManager *p_oSimManager);

/**
  * Performs the ninth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        -5-20, 21-40	   1	 AbsBA	        6, 6             Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

    void DoSelectionHarvestRun9(clSimManager *p_oSimManager);

/**
  * Performs the tenth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	        "bad", 21-40	   1	 AbsBA	        6, 6             Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

    void DoSelectionHarvestRun10(clSimManager *p_oSimManager);

/**
  * Performs the eleventh harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        1	         none	          1	 AbsBA	        N/A            Whole plot
  * The harvest will not be performed.  An error message will be thrown.
  */

    void DoSelectionHarvestRun11(clSimManager *p_oSimManager);

/**
  * Performs the twelth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        2	         0-100	          1	 AbsBA	        6            Whole plot
  * The harvest will be performed.  The purpose of the run is to test the
  * TimeSinceHarvest function.  Each cell will be given an intial age of 5000 years.
  * They will be cut as the target BA is lower than initial BA.  The timeSinceHarvest
  * function will reflect this by returning the timestep length as the amount of
  * time elapsed since harvest
  */


    void DoSelectionHarvestRun12(clSimManager *p_oSimManager);

/**
  * Performs the thirteenth harvest run.  This run has the following characteristics:
  * Harvest #	Timestep	Cut Ranges	Species	Cut Type  Target BA Amt (abs)	Grids
  * 1	        2	         0-100	          1	 AbsBA	        500            Whole plot
  * The harvest will not be performed.  The purpose of the run is to test the
  * TimeSinceHarvest function.  Each cell will be given an intial age of 5000 years.
  * They will not be cut as the target BA is too high.  The timeSinceHarvest
  * function will reflect this by returning the initial age + timestep length (5000+1)
  */

    void DoSelectionHarvestRun13(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file to test disturbance for run 1.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file to test disturbance for run 2.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file to test disturbance for run 3.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile3();

  /**
  * Writes a parameter file to test disturbance for run 4.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile4();

  /**
  * Writes a parameter file to test disturbance for run 5.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile5();

  /**
  * Writes a parameter file to test disturbance for run 6.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile6();

  /**
  * Writes a parameter file to test disturbance for run 7.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile7();

/**
  * Writes a parameter file to test disturbance for run 8.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile8();

/**
  * Writes a parameter file to test disturbance for run 9.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile9();

/**
  * Writes a parameter file to test disturbance for run 10.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile10();

/**
  * Writes a parameter file to test disturbance for run 11.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile11();

  /**
  * Writes a parameter file to test disturbance for run 12.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile12();

  /**
  * Writes a parameter file to test disturbance for run 12.  This has a tree
  * map so an expected tree set is created.
  * @return Filename written.
  */
  char * WriteXMLFile13();

  /**
  * Writes the tree map for harvest parameter files.
  * @param oOut Filestream to write to.
  */
  void WriteTreeMap(char *cFileName);

  /**
  * Checks the results of the tree population against the expected results.
  */
  void CheckResults(clTreePopulation *p_oPop, int iNumTrees, tree *p_FakeTrees);

};
//---------------------------------------------------------------------------
#endif // TestSelectionHarvest_H
