//---------------------------------------------------------------------------
// TestStochasticMort_H
//---------------------------------------------------------------------------
#if !defined(TestStochasticMort_H)
  #define TestStochasticMort_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

/**
* Tests the clStochasticMort class.
*/
class clTestStochasticMort : public CppUnit::TestFixture
{
  public:

/**
* This performs a test of stochastic mortality.  An XML file is written with
* different species getting different mortality levels.  This will add 1000
* trees of each species, run mortality, and then count the remaining trees to
* make sure the correct number were killed.  This is repeated with a file with
* a different number of years per timestep.
*/
  void TestStochasticMortality();

  protected:

  /**
  * Writes a parameter file for testing.  There are four species: one whose
  * mortality rate is 0, one whose mortality rate is 1, one whose mortality
  * rate is 0.25, and one to which mortality does not apply.  The number of
  * years per timestep is 1.  The behavior is adult stochastic mortality.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file for testing.  This is the same as WriteXMLFile1(),
  * except the number of years per timestep is 3 and it's juvenile stochastic
  * mortality.
  * @return Filename written.
  */
  char * WriteXMLFile2();


};
#endif // TestStochasticMort_H
//---------------------------------------------------------------------------


