//---------------------------------------------------------------------------
// TestSubstrateDepSeedSurvival.cpp
//---------------------------------------------------------------------------
#include "TestSubstrateDepSeedSurvival.h"
#include "GridBase.h"
#include "SimManager.h"
#include "BehaviorBase.h"
#include "TreePopulation.h"
#include <stdio.h>
#include <fstream.h>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestEstablishment1()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::TestSubstrateDepSeedSurvival() {
  clSimManager *p_oSimManager = new clSimManager(3, 3, "");

  TestNormalProcessingRun1(p_oSimManager);
  TestNormalProcessingRun2(p_oSimManager);
  TestNormalProcessingRun3(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  //Clean up
  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::TestErrorProcessing(clSimManager *p_oSimManager) {

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clSubstrateDepSeedSurvival::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clSubstrateDepSeedSurvival::SetupGrids") == NULL)
    {
      CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clSubstrateDepSeedSurvival::SetupGrids") == NULL)
    {
      CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

/*  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clSubstrateDepSeedSurvival::GetData") == NULL)
    {
      CppUnit::Asserter::fail("TestSubstrateDepSeedSurvival error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  } */
}

/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessingRun1()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::TestNormalProcessingRun1(clSimManager *p_oSimManager) {

   //Feed our file to the sim manager
   p_oSimManager->ReadFile(WriteXMLFile1());

   clGridBase *p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
   clGridBase *p_oSubstrate = p_oSimManager->GetGridObject("Substrate");
   clGridBase *p_oSubsFav = p_oSimManager->GetGridObject("Substrate Favorability");
   clTreePopulation *p_oPop = (clTreePopulation*)p_oSimManager->GetPopulationObject("treepopulation");
   float fValue, fExpectedFav;
   clTreeSearch *p_oAllSeedlings;
   clTree *p_oTree;
   float fX, fY, fMin, fMax;
   int *p_iNumSeedlings = new int[7], i;

   //For each of four cells, set 1000 seeds of each species
   fValue = 1000;
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);

   //Set the substrate proportions for these same cells
   fValue = 0;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.42;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.01;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.345;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.225;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 1;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.88;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.02;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.04;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.21;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.22;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.23;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.24;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.1;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   //Do the run but don't let substrate run
   clBehaviorBase * p_oTempBehavior;
   char cBehaviorName[MAX_NAMESTRING_SIZE];
   for (i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
     p_oTempBehavior = p_oSimManager->GetBehaviorObject( i );
     strcpy( cBehaviorName, p_oTempBehavior->GetName() );
     if ( strcmp( cBehaviorName, "substrate" ) != 0 )
     {
       p_oTempBehavior->Action();
     }
   }

   //Check the substrate favorabilities
   fExpectedFav = 0.529265;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.256355;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.95625;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.370335;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.502265;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.673575;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.462;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.98;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.278;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.462;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 1;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.06529;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.05423;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.9597;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.84609;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.06169;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.05093;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.31499;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.22181;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.9649;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.40866;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.30299;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.3743;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   //Count the seedlings
   p_oAllSeedlings = p_oPop->Find("type=1");

   //Check our values for cell 0, 0
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 0;
   fMax = 8;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(529.265 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(256.355 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(956.25 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(370.335 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(502.265 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(673.575 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 1, 1
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 8;
   fMax = 16;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(462 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(0 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(980 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(278 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(462 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(1000 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 2, 2
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 16;
   fMax = 24;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(65.29 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(54.23 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(959.7 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(846.09 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(61.69 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(50.93 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);


   //Check our values for cell 3, 3
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 24;
   fMax = 32;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(314.99 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(221.81 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(964.9 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(408.66 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(302.99 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(374.3 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessingRun2()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::TestNormalProcessingRun2(clSimManager *p_oSimManager) {

   //Feed our file to the sim manager
   p_oSimManager->ReadFile(WriteXMLFile2());

   clGridBase *p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
   clGridBase *p_oSubstrate = p_oSimManager->GetGridObject("Substrate");
   clGridBase *p_oSubsFav = p_oSimManager->GetGridObject("Substrate Favorability");
   clTreePopulation *p_oPop = (clTreePopulation*)p_oSimManager->GetPopulationObject("treepopulation");
   float fValue, fExpectedFav;
   clTreeSearch *p_oAllSeedlings;
   clTree *p_oTree;
   float fX, fY, fMin, fMax;
   int *p_iNumSeedlings = new int[7], i;

   //For each of four cells, set 1000 seeds of each species
   fValue = 1000;
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(1, 1, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(2, 2, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(3, 3, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(5, 5, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(6, 6, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(7, 7, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);

   //Set the substrate proportions for these same cells
   fValue = 0;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.42;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.01;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.345;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.225;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 1;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.88;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.02;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.04;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(2, 2, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.21;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.22;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.23;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.24;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.1;
   p_oSubstrate->SetValueOfCell(3, 3, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0;
   p_oSubstrate->SetValueOfCell(4, 4, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.42;
   p_oSubstrate->SetValueOfCell(4, 4, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.01;
   p_oSubstrate->SetValueOfCell(4, 4, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.345;
   p_oSubstrate->SetValueOfCell(4, 4, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.225;
   p_oSubstrate->SetValueOfCell(4, 4, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0;
   p_oSubstrate->SetValueOfCell(5, 5, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 1;
   p_oSubstrate->SetValueOfCell(5, 5, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(5, 5, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(5, 5, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(5, 5, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.88;
   p_oSubstrate->SetValueOfCell(6, 6, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.02;
   p_oSubstrate->SetValueOfCell(6, 6, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(6, 6, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.04;
   p_oSubstrate->SetValueOfCell(6, 6, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.03;
   p_oSubstrate->SetValueOfCell(6, 6, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.21;
   p_oSubstrate->SetValueOfCell(7, 7, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.22;
   p_oSubstrate->SetValueOfCell(7, 7, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.23;
   p_oSubstrate->SetValueOfCell(7, 7, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.24;
   p_oSubstrate->SetValueOfCell(7, 7, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.1;
   p_oSubstrate->SetValueOfCell(7, 7, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   //Create the trees that will create non-gap conditions
   p_oPop->CreateTree(36, 36, 0, clTreePopulation::adult, 20);
   p_oPop->CreateTree(44, 44, 0, clTreePopulation::adult, 20);
   p_oPop->CreateTree(52, 52, 0, clTreePopulation::adult, 20);
   p_oPop->CreateTree(60, 60, 0, clTreePopulation::adult, 20);

   //Do the run but don't let substrate run
   clBehaviorBase * p_oTempBehavior;
   char cBehaviorName[MAX_NAMESTRING_SIZE];
   for (i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
     p_oTempBehavior = p_oSimManager->GetBehaviorObject( i );
     strcpy( cBehaviorName, p_oTempBehavior->GetName() );
     if ( strcmp( cBehaviorName, "substrate" ) != 0 )
     {
       p_oTempBehavior->Action();
     }
   }

   //Check the substrate favorabilities
   fExpectedFav = 0.349945;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.32914;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.358165;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.33604;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.349945;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.31906;
   p_oSubsFav->GetValueOfCell(0, 0, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.353;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.024;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.353;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.024;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.353;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0;
   p_oSubsFav->GetValueOfCell(1, 1, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.9006;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.42255;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.92526;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.44325;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.9006;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.42207;
   p_oSubsFav->GetValueOfCell(2, 2, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.38759;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.34184;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.57665;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.50054;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.38759;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.33656;
   p_oSubsFav->GetValueOfCell(3, 3, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.529265;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.256355;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.95625;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.370335;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.502265;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.673575;
   p_oSubsFav->GetValueOfCell(4, 4, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.462;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.98;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.278;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.462;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 1;
   p_oSubsFav->GetValueOfCell(5, 5, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.06529;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.05423;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.9597;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.84609;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.06169;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.05093;
   p_oSubsFav->GetValueOfCell(6, 6, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   fExpectedFav = 0.31499;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index1"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.22181;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index2"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.9649;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index3"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.40866;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index4"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.30299;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index5"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);
   fExpectedFav = 0.3743;
   p_oSubsFav->GetValueOfCell(7, 7, p_oSubsFav->GetFloatDataCode("Favorability Index6"), &fValue);
   CPPUNIT_ASSERT(fabs(fExpectedFav - fValue) < 0.001);

   //Count the seedlings
   p_oAllSeedlings = p_oPop->Find("type=1");

   //Check our values for cell 0, 0
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 0;
   fMax = 8;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(349.945 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(329.14 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(358.165 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(336.04 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(349.945 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(319.06 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 1, 1
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 8;
   fMax = 16;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(353 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(24 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.15);
   CPPUNIT_ASSERT(fabs(353 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(24 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(353 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(0 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 2, 2
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 16;
   fMax = 24;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(900.6 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(422.55 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(925.26 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(443.25 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(900.6 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(422.07 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 3, 3
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 24;
   fMax = 32;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(387.59 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(341.84 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(576.65 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(500.54 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(387.59 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(336.56 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 4, 4
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 32;
   fMax = 40;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(529.265 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(256.355 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(956.25 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(370.335 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(502.265 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(673.575 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 5, 5
   p_oAllSeedlings->StartOver();
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 40;
   fMax = 48;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(462 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(0 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(980 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(278 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.13);
   CPPUNIT_ASSERT(fabs(462 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(1000 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   //Check our values for cell 6, 6
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 48;
   fMax = 56;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(65.29 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(54.23 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.16);
   CPPUNIT_ASSERT(fabs(959.7 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(846.09 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(61.69 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(50.93 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);


   //Check our values for cell 7, 7
   p_oAllSeedlings->StartOver();
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 56;
   fMax = 64;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(314.99 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(221.81 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.11);
   CPPUNIT_ASSERT(fabs(964.9 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(408.66 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(302.99 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(374.3 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessingRun3()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::TestNormalProcessingRun3(clSimManager *p_oSimManager) {

   //Feed our file to the sim manager
   p_oSimManager->ReadFile(WriteXMLFile3());

   clGridBase *p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
   clGridBase *p_oSubstrate = p_oSimManager->GetGridObject("Substrate");
   clTreePopulation *p_oPop = (clTreePopulation*)p_oSimManager->GetPopulationObject("treepopulation");
   float fValue, fExpectedFav;
   clTreeSearch *p_oAllSeedlings;
   clTree *p_oTree;
   float fX, fY, fMin, fMax;
   int *p_iNumSeedlings = new int[7], i;

   //For cell 0, 0, set 1000 seeds of each species
   fValue = 1000;
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_4"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_5"), fValue);
   p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_6"), fValue);

   //Set the substrate proportions for four cells
   fValue = 0;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.01;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.11;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.88;
   p_oSubstrate->SetValueOfCell(0, 0, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.17;
   p_oSubstrate->SetValueOfCell(0, 1, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.06;
   p_oSubstrate->SetValueOfCell(0, 1, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.04;
   p_oSubstrate->SetValueOfCell(0, 1, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.15;
   p_oSubstrate->SetValueOfCell(0, 1, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.58;
   p_oSubstrate->SetValueOfCell(0, 1, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.45;
   p_oSubstrate->SetValueOfCell(1, 0, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.09;
   p_oSubstrate->SetValueOfCell(1, 0, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0;
   p_oSubstrate->SetValueOfCell(1, 0, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.34;
   p_oSubstrate->SetValueOfCell(1, 0, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.12;
   p_oSubstrate->SetValueOfCell(1, 0, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   fValue = 0.36;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("gapmoss"), fValue);
   fValue = 0.17;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("freshlog"), fValue);
   fValue = 0.01;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("mossylog"), fValue);
   fValue = 0.34;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("organic"), fValue);
   fValue = 0.12;
   p_oSubstrate->SetValueOfCell(1, 1, p_oSubstrate->GetFloatDataCode("canmoss"), fValue);

   //Do the run but don't let substrate run
   clBehaviorBase * p_oTempBehavior;
   char cBehaviorName[MAX_NAMESTRING_SIZE];
   for (i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
     p_oTempBehavior = p_oSimManager->GetBehaviorObject( i );
     strcpy( cBehaviorName, p_oTempBehavior->GetName() );
     if ( strcmp( cBehaviorName, "substrate" ) != 0 )
     {
       p_oTempBehavior->Action();
     }
   }

   //Count the seedlings
   p_oAllSeedlings = p_oPop->Find("type=1");

   //Check our values for cell 0, 0
   for (i = 0; i < 7; i++) {
     p_iNumSeedlings[i] = 0;
   }
   fMin = 0;
   fMax = 16;
   p_oTree = p_oAllSeedlings->NextTree();
   while (p_oTree) {
     p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
     p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
     if (fX >= fMin && fX < fMax && fY >= fMin && fY < fMax) {
       p_iNumSeedlings[p_oTree->GetSpecies()]++;
     }
     p_oTree = p_oAllSeedlings->NextTree();
   }
   CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
   CPPUNIT_ASSERT(fabs(537.1275 - p_iNumSeedlings[1])/p_iNumSeedlings[1] < 0.1);
   CPPUNIT_ASSERT(fabs(281.06 - p_iNumSeedlings[2])/p_iNumSeedlings[2] < 0.1);
   CPPUNIT_ASSERT(fabs(943.775 - p_iNumSeedlings[3])/p_iNumSeedlings[3] < 0.1);
   CPPUNIT_ASSERT(fabs(514.11 - p_iNumSeedlings[4])/p_iNumSeedlings[4] < 0.1);
   CPPUNIT_ASSERT(fabs(486.1275 - p_iNumSeedlings[5])/p_iNumSeedlings[5] < 0.1);
   CPPUNIT_ASSERT(fabs(348.275 - p_iNumSeedlings[6])/p_iNumSeedlings[6] < 0.1);

   delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteCommonStuff(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>No Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_6\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_7\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_5\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_4\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>0</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>0</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>0</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_3\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_4\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_5\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_6\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_7\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_3\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_4\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_5\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_6\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_7\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_3\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_4\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_5\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_6\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_7\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_5\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_6\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_7\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_5\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_6\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_7\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_5\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_6\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_7\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_3\">0.017</es_sscfVal>"
       << "<es_sscfVal species=\"Species_4\">0.96</es_sscfVal>"
       << "<es_sscfVal species=\"Species_5\">0.92</es_sscfVal>"
       << "<es_sscfVal species=\"Species_6\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_7\">0</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_3\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_4\">0.95</es_tucfVal>"
       << "<es_tucfVal species=\"Species_5\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_6\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_7\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_3\">0</es_flcfVal>"
       << "<es_flcfVal species=\"Species_4\">0.98</es_flcfVal>"
       << "<es_flcfVal species=\"Species_5\">0.278</es_flcfVal>"
       << "<es_flcfVal species=\"Species_6\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_7\">1</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_3\">0.278</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_4\">0.99</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_5\">0</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_6\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_7\">0</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_3\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_4\">0.92</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_5\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_6\">0.88</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_7\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteCommonStuff(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>gap disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_6\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_7\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_5\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_4\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0.0080</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_3\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_4\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_5\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_6\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_7\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_3\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_4\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_5\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_6\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_7\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_3\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_4\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_5\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_6\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_7\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_5\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_6\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_7\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_weibullCanopySTR>"
       << "<di_wcsVal species=\"Species_7\">0</di_wcsVal>"
       << "<di_wcsVal species=\"Species_6\">0</di_wcsVal>"
       << "<di_wcsVal species=\"Species_5\">0</di_wcsVal>"
       << "<di_wcsVal species=\"Species_4\">0</di_wcsVal>"
       << "<di_wcsVal species=\"Species_3\">0</di_wcsVal>"
       << "<di_wcsVal species=\"Species_2\">0</di_wcsVal>"
       << "</di_weibullCanopySTR>"
       << "<di_weibullCanopyBeta>"
       << "<di_wcbVal species=\"Species_7\">2.0</di_wcbVal>"
       << "<di_wcbVal species=\"Species_6\">2.0</di_wcbVal>"
       << "<di_wcbVal species=\"Species_5\">2.0</di_wcbVal>"
       << "<di_wcbVal species=\"Species_4\">2.0</di_wcbVal>"
       << "<di_wcbVal species=\"Species_3\">2.0</di_wcbVal>"
       << "<di_wcbVal species=\"Species_2\">2.0</di_wcbVal>"
       << "</di_weibullCanopyBeta>"
       << "<di_weibullCanopyDispersal>"
       << "<di_wcdVal species=\"Species_7\">1.76E-4</di_wcdVal>"
       << "<di_wcdVal species=\"Species_6\">1.76E-4</di_wcdVal>"
       << "<di_wcdVal species=\"Species_5\">1.76E-4</di_wcdVal>"
       << "<di_wcdVal species=\"Species_4\">1.76E-4</di_wcdVal>"
       << "<di_wcdVal species=\"Species_3\">1.76E-4</di_wcdVal>"
       << "<di_wcdVal species=\"Species_2\">1.76E-4</di_wcdVal>"
       << "</di_weibullCanopyDispersal>"
       << "<di_weibullCanopyTheta>"
       << "<di_wctVal species=\"Species_7\">3.0</di_wctVal>"
       << "<di_wctVal species=\"Species_6\">3.0</di_wctVal>"
       << "<di_wctVal species=\"Species_5\">3.0</di_wctVal>"
       << "<di_wctVal species=\"Species_4\">3.0</di_wctVal>"
       << "<di_wctVal species=\"Species_3\">3.0</di_wctVal>"
       << "<di_wctVal species=\"Species_2\">3.0</di_wctVal>"
       << "</di_weibullCanopyTheta>"
       << "<di_weibullGapSTR>"
       << "<di_wgsVal species=\"Species_7\">0</di_wgsVal>"
       << "<di_wgsVal species=\"Species_6\">0</di_wgsVal>"
       << "<di_wgsVal species=\"Species_5\">0</di_wgsVal>"
       << "<di_wgsVal species=\"Species_4\">0</di_wgsVal>"
       << "<di_wgsVal species=\"Species_3\">0</di_wgsVal>"
       << "<di_wgsVal species=\"Species_2\">0</di_wgsVal>"
       << "</di_weibullGapSTR>"
       << "<di_weibullGapBeta>"
       << "<di_wgbVal species=\"Species_2\">2.3</di_wgbVal>"
       << "<di_wgbVal species=\"Species_3\">2.3</di_wgbVal>"
       << "<di_wgbVal species=\"Species_4\">2.3</di_wgbVal>"
       << "<di_wgbVal species=\"Species_5\">2.3</di_wgbVal>"
       << "<di_wgbVal species=\"Species_6\">2.3</di_wgbVal>"
       << "<di_wgbVal species=\"Species_7\">2.3</di_wgbVal>"
       << "</di_weibullGapBeta>"
       << "<di_weibullGapDispersal>"
       << "<di_wgdVal species=\"Species_2\">1.32E-4</di_wgdVal>"
       << "<di_wgdVal species=\"Species_3\">1.32E-4</di_wgdVal>"
       << "<di_wgdVal species=\"Species_4\">1.32E-4</di_wgdVal>"
       << "<di_wgdVal species=\"Species_5\">1.32E-4</di_wgdVal>"
       << "<di_wgdVal species=\"Species_6\">1.32E-4</di_wgdVal>"
       << "<di_wgdVal species=\"Species_7\">1.32E-4</di_wgdVal>"
       << "</di_weibullGapDispersal>"
       << "<di_weibullGapTheta>"
       << "<di_wgtVal species=\"Species_2\">3.0</di_wgtVal>"
       << "<di_wgtVal species=\"Species_3\">3.0</di_wgtVal>"
       << "<di_wgtVal species=\"Species_4\">3.0</di_wgtVal>"
       << "<di_wgtVal species=\"Species_5\">3.0</di_wgtVal>"
       << "<di_wgtVal species=\"Species_6\">3.0</di_wgtVal>"
       << "<di_wgtVal species=\"Species_7\">3.0</di_wgtVal>"
       << "</di_weibullGapTheta>"
       << "<di_maxGapDensity>0</di_maxGapDensity>"
       << "<di_gapFunction>"
       << "<di_gfVal species=\"Species_7\">0</di_gfVal>"
       << "<di_gfVal species=\"Species_6\">0</di_gfVal>"
       << "<di_gfVal species=\"Species_5\">0</di_gfVal>"
       << "<di_gfVal species=\"Species_4\">0</di_gfVal>"
       << "<di_gfVal species=\"Species_3\">0</di_gfVal>"
       << "<di_gfVal species=\"Species_2\">0</di_gfVal>"
       << "</di_gapFunction>"
       << "<di_canopyFunction>"
       << "<di_cfVal species=\"Species_7\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_6\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_5\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_4\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_3\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_2\">0</di_cfVal>"
       << "</di_canopyFunction>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_3\">0.017</es_sscfVal>"
       << "<es_sscfVal species=\"Species_4\">0.96</es_sscfVal>"
       << "<es_sscfVal species=\"Species_5\">0.92</es_sscfVal>"
       << "<es_sscfVal species=\"Species_6\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_7\">0</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_3\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_4\">0.95</es_tucfVal>"
       << "<es_tucfVal species=\"Species_5\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_6\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_7\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_3\">0</es_flcfVal>"
       << "<es_flcfVal species=\"Species_4\">0.98</es_flcfVal>"
       << "<es_flcfVal species=\"Species_5\">0.278</es_flcfVal>"
       << "<es_flcfVal species=\"Species_6\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_7\">1</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_3\">0.278</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_4\">0.99</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_5\">0</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_6\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_7\">0</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_3\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_4\">0.92</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_5\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_6\">0.88</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_7\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "<es_scarifiedSoilGapFav>"
       << "<es_ssgfVal species=\"Species_2\">0.983</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_3\">0.424</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_4\">0.983</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_5\">0.424</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_6\">0.983</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_7\">0.424</es_ssgfVal>"
       << "</es_scarifiedSoilGapFav>"
       << "<es_tipUpGapFav>"
       << "<es_tugfVal species=\"Species_2\">0.009</es_tugfVal>"
       << "<es_tugfVal species=\"Species_3\">0.413</es_tugfVal>"
       << "<es_tugfVal species=\"Species_4\">0.009</es_tugfVal>"
       << "<es_tugfVal species=\"Species_5\">0.413</es_tugfVal>"
       << "<es_tugfVal species=\"Species_6\">0.009</es_tugfVal>"
       << "<es_tugfVal species=\"Species_7\">0.413</es_tugfVal>"
       << "</es_tipUpGapFav>"
       << "<es_freshLogGapFav>"
       << "<es_flgfVal species=\"Species_2\">0.353</es_flgfVal>"
       << "<es_flgfVal species=\"Species_3\">0.024</es_flgfVal>"
       << "<es_flgfVal species=\"Species_4\">0.353</es_flgfVal>"
       << "<es_flgfVal species=\"Species_5\">0.024</es_flgfVal>"
       << "<es_flgfVal species=\"Species_6\">0.353</es_flgfVal>"
       << "<es_flgfVal species=\"Species_7\">0</es_flgfVal>"
       << "</es_freshLogGapFav>"
       << "<es_decayedLogGapFav>"
       << "<es_dlgfVal species=\"Species_2\">0.058</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_3\">0.31</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_4\">0.88</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_5\">1</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_6\">0.058</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_7\">0.31</es_dlgfVal>"
       << "</es_decayedLogGapFav>"
       << "<es_forestFloorGapFav>"
       << "<es_ffgfVal species=\"Species_2\">0.88</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_3\">0.771</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_4\">0.88</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_5\">0.771</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_6\">0.88</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_7\">0.771</es_ffgfVal>"
       << "</es_forestFloorGapFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteCommonStuff(oOut);

  oOut << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_3\">3</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_4\">4</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_5\">5</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_6\">5</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">1</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>16</ma_lengthXCells>"
       << "<ma_lengthYCells>16</ma_lengthYCells>";

  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_6\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_7\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>No Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_6\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_7\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_6\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_7\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_5\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_4\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0.0080</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_3\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_4\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_5\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_6\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_7\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_3\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_4\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_5\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_6\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_7\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_3\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_4\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_5\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_6\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_7\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_5\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_6\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_7\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_5\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_6\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_7\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_5\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_6\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_7\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_3\">0.017</es_sscfVal>"
       << "<es_sscfVal species=\"Species_4\">0.96</es_sscfVal>"
       << "<es_sscfVal species=\"Species_5\">0.92</es_sscfVal>"
       << "<es_sscfVal species=\"Species_6\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_7\">0</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_3\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_4\">0.95</es_tucfVal>"
       << "<es_tucfVal species=\"Species_5\">0.48</es_tucfVal>"
       << "<es_tucfVal species=\"Species_6\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_7\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_3\">0</es_flcfVal>"
       << "<es_flcfVal species=\"Species_4\">0.98</es_flcfVal>"
       << "<es_flcfVal species=\"Species_5\">0.278</es_flcfVal>"
       << "<es_flcfVal species=\"Species_6\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_7\">1</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_3\">0.278</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_4\">0.99</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_5\">0</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_6\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_7\">0</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_3\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_4\">0.92</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_5\">0.391</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_6\">0.88</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_7\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLErrorFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>No Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0.0080</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_1\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_1\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_1\">0.017</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_1\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_1\">0</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">1.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_1\">0.278</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_1\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLErrorFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>No Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_1\">0.017</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_1\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_1\">0</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_1\">0.278</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_1\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLErrorFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>No Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0.0080</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_1\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_1\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_1\">0.017</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_1\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_1\">0</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_1\">0.278</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_1\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrateDepSeedSurvival::WriteXMLErrorFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Gap Substrate Seed Survival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_freshLogFromCanMoss>0.0080</su_freshLogFromCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_1\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_2\">0</su_pofuVal>"
       << "<su_pofuVal species=\"Species_1\">0</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_areaOrgExposed>3.0</su_areaOrgExposed>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>"
       << "</substrate>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<establishment>"
       << "<es_scarifiedSoilCanopyFav>"
       << "<es_sscfVal species=\"Species_2\">0.01</es_sscfVal>"
       << "<es_sscfVal species=\"Species_1\">0.017</es_sscfVal>"
       << "</es_scarifiedSoilCanopyFav>"
       << "<es_tipUpCanopyFav>"
       << "<es_tucfVal species=\"Species_2\">0.315</es_tucfVal>"
       << "<es_tucfVal species=\"Species_1\">0.48</es_tucfVal>"
       << "</es_tipUpCanopyFav>"
       << "<es_freshLogCanopyFav>"
       << "<es_flcfVal species=\"Species_2\">0.462</es_flcfVal>"
       << "<es_flcfVal species=\"Species_1\">0</es_flcfVal>"
       << "</es_freshLogCanopyFav>"
       << "<es_decayedLogCanopyFav>"
       << "<es_dlcfVal species=\"Species_2\">0.155</es_dlcfVal>"
       << "<es_dlcfVal species=\"Species_1\">0.278</es_dlcfVal>"
       << "</es_decayedLogCanopyFav>"
       << "<es_forestFloorCanopyFav>"
       << "<es_ffcfVal species=\"Species_2\">1</es_ffcfVal>"
       << "<es_ffcfVal species=\"Species_1\">0.391</es_ffcfVal>"
       << "</es_forestFloorCanopyFav>"
       << "<es_scarifiedSoilGapFav>"
       << "<es_ssgfVal species=\"Species_2\">0.983</es_ssgfVal>"
       << "<es_ssgfVal species=\"Species_1\">0.424</es_ssgfVal>"
       << "</es_scarifiedSoilGapFav>"
       << "<es_tipUpGapFav>"
       << "<es_tugfVal species=\"Species_2\">0.009</es_tugfVal>"
       << "<es_tugfVal species=\"Species_1\">0.413</es_tugfVal>"
       << "</es_tipUpGapFav>"
       << "<es_freshLogGapFav>"
       << "<es_flgfVal species=\"Species_2\">0.353</es_flgfVal>"
       << "<es_flgfVal species=\"Species_1\">0.024</es_flgfVal>"
       << "</es_freshLogGapFav>"
       << "<es_decayedLogGapFav>"
       << "<es_dlgfVal species=\"Species_2\">0.058</es_dlgfVal>"
       << "<es_dlgfVal species=\"Species_1\">0.31</es_dlgfVal>"
       << "</es_decayedLogGapFav>"
       << "<es_forestFloorGapFav>"
       << "<es_ffgfVal species=\"Species_2\">0.88</es_ffgfVal>"
       << "<es_ffgfVal species=\"Species_1\">0.771</es_ffgfVal>"
       << "</es_forestFloorGapFav>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrateDepSeedSurvival::WriteCommonStuff( std::fstream &oOut )
{
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "<tr_species speciesName=\"Species_5\" />"
       << "<tr_species speciesName=\"Species_6\" />"
       << "<tr_species speciesName=\"Species_7\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_5\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_6\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_7\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_5\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_6\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_7\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_5\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_6\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_7\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_4\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_5\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_6\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_7\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_4\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_5\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_6\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_7\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_5\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_6\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_7\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_4\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_5\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_6\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_7\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_4\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_5\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_6\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_7\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_5\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_6\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_7\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_5\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_6\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_7\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_5\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_6\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_7\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_5\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_6\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_7\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_5\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_6\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_7\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>";
}
