//---------------------------------------------------------------------------
// TestTree.cpp
//---------------------------------------------------------------------------
#include "TestTree.h"
#include "TreePopulation.h"
#include "SimManager.h"
#include <fstream.h>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestTree()
/////////////////////////////////////////////////////////////////////////////
void clTestTree::TestTree()
{

  clSimManager *p_oSimManager = new clSimManager(2, 4, "");

  TestAllometryUpdating(p_oSimManager);

  delete p_oSimManager;
}


/////////////////////////////////////////////////////////////////////////////
//  TestAllometryUpdating()
/////////////////////////////////////////////////////////////////////////////
void clTestTree::TestAllometryUpdating(clSimManager *p_oSimManager)
{
  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTree;
  float fDiam, fDBH, fHeight, fTemp;
  int iSp, iTp;

  //Set up our run and get the tree popluation pointer
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //*************************
  //Create a seedling
  //*************************
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();

  //Change the diameter at 10 cm and allow the allometry to update
  fDiam = 0.2;
  fHeight = 0.304380631;
  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and allow the allometry to update
  fHeight = 0.7;
  fDiam = 0.59106809;
  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //Change the diameter at 10 cm and do not allow the allometry to update
  fDiam = 1.0;
  fHeight = 0.7;
  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and do not allow the allometry to update
  fHeight = 1.2;
  fDiam = 1.0;
  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, false);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //*************************
  //Create a sapling
  //*************************
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();

  //Change the diameter at 10 cm and allow the allometry to update
  fDiam = 7.8;
  fHeight = 7.845800505;
  fDBH = 6.24624;
  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Change the DBH and allow the allometry to update
  fDBH = 5.0;
  fDiam = 6.243756244;
  fHeight = 6.644791358;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, true);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //Change the height and allow the allometry to update
  fHeight = 8.0;
  fDBH = 6.40966389;
  fDiam = 8.004075787;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //Change the diameter at 10 cm and do not allow the allometry to update
  fDiam = 3.0;
  fHeight = 8.0;
  fDBH = 2.4024;
  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Change the DBH and do not allow the allometry to update
  fDBH = 5.0;
  fDiam = 6.243756244;
  fHeight = 8.0;
  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //Change the height and do not allow the allometry to update
  fHeight = 9.0;
  fDBH = 5.0;
  fDiam = 6.243756244;
  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, false);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //*************************
  //Create an adult
  //*************************
  fDiam = 15.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::adult, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();

  //Change the DBH and allow the allometry to update
  fDBH = 17.0;
  fHeight = 16.54414575;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and allow the allometry to update
  fHeight = 18.0;
  fDBH = 19.19328108;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Change the DBH and do not allow the allometry to update
  fDBH = 27.0;
  fHeight = 18.0;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and do not allow the allometry to update
  fDBH = 37.0;
  fHeight = 18.0;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //*************************
  //Create a snag
  //*************************

  fDiam = 15.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::snag, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();

  //Change the DBH and allow the allometry to update
  fDBH = 17.0;
  fHeight = 16.54414575;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, true);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and allow the allometry to update
  fHeight = 18.0;
  fDBH = 19.19328108;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, true);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Change the DBH and do not allow the allometry to update
  fDBH = 27.0;
  fHeight = 18.0;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Change the height and do not allow the allometry to update
  fDBH = 37.0;
  fHeight = 18.0;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //*************************
  //Seedling to sapling transition
  //*************************
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  //Allowing allometry to update - push diam10 over the limit
  fDiam = 5.0;
  fHeight = 5.652239774;
  fDBH = 4.004;

  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  iTp = p_oTree->GetType();
  iSp = p_oTree->GetSpecies();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Allowing allometry to update - make sure the seedling uses its own max
  //height to assess sapling transition; this one shouldn't push it over
  //the limit
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 1, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fDiam = 1.4;
  fHeight = 1.50175416;
  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Now this one should cause the transition
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 1, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fDiam = 5.0;
  fHeight = 5.652239774;
  fDBH = 4.004;

  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(p_oTree->GetSpecies(), iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Allowing allometry to update - push height over the limit
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fHeight = 2.0;
  fDiam = 0.718091127;
  fDBH = 0.575047375;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Allowing allometry to update - make sure that the seedling uses its own
  //max height - this one should not transition
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 1, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fHeight = 1.5;
  fDiam = 1.398205496;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);

  //Now this should push it over the transition
  fHeight = 2.0;
  fDiam = 0.718091127;
  fDBH = 0.575047375;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Not allowing allometry to update - push diam10 over the limit - it should
  //not transition to sapling
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fDiam = 5.0;
  fHeight = 0.202364959;

  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, false);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Not allowing allometry to update - push height over the limit - it should
  //transition but diam10 should be the same
  fDiam = 0.1;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::seedling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::seedling == iTp);

  fHeight = 3.0;
  fDiam = 0.1;
  fDBH = 0.08008;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, false);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetDiam10Code(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDiam - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //*************************
  //Sapling to adult transition
  //*************************

  //Allowing allometry to update - push diam10 over the limit
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fDiam = 13.0;
  fDBH = 10.4104;
  fHeight = 11.54918907;

  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::adult == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Allowing allometry to update - push DBH over the limit
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fDBH = 15;
  fHeight = 15.13074207;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::adult == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Allowing allometry to update - push height over the limit
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fHeight = 20;
  fDBH = 22.46197577;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, true);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::adult == iTp);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Not allowing allometry to update - push diam10 over the limit - it should
  //transition to adult
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fDiam = 13.0;
  fDBH = 10.4104;
  fHeight = 6.644791358;

  p_oTree->SetValue(p_oPop->GetDiam10Code(iSp, iTp), fDiam, true, false);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::adult == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);

  //Allowing allometry to update - push DBH over the limit - it should
  //transition to adult with diam10 and height the same
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fDBH = 15;
  fHeight = 6.644791358;

  p_oTree->SetValue(p_oPop->GetDbhCode(iSp, iTp), fDBH, true, false);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::adult == iTp);
  p_oTree->GetValue(p_oPop->GetHeightCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fHeight - fTemp) < 0.001);

  //Not allowing allometry to update - push height over the limit - it should
  //not transition to adult
  fDiam = 5.0;
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::sapling, fDiam);
  iSp = p_oTree->GetSpecies();
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);

  fHeight = 20;
  fDBH = 5.0;

  p_oTree->SetValue(p_oPop->GetHeightCode(iSp, iTp), fHeight, true, false);
  iTp = p_oTree->GetType();
  CPPUNIT_ASSERT(clTreePopulation::sapling == iTp);
  p_oTree->GetValue(p_oPop->GetDbhCode(iSp, iTp), &fTemp);
  CPPUNIT_ASSERT(fabs(fDBH - fTemp) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestTree::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";
  int i, j;

  //Open file to write to
  std::fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.6</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

