//---------------------------------------------------------------------------
// TestTreePopulation2
//---------------------------------------------------------------------------
#if !defined(TestTreePopulation2_H)
  #define TestTreePopulation2_H

#include <cppunit/TestFixture.h>

class clSimManager;

/**
* Tests the clTreePopulation class.  This is because TestTreePopulation got
* too big.
*/
class clTestTreePopulation2 : public CppUnit::TestFixture
{
  public:

  /**
  * Combines all the tests for testing the tree population.
  */
  void TestTreePopulation();

  protected:

  /**
  * Makes sure that tree maps are read correctly.  This includes trees of every
  * tree type, with each type defined by either diameter or height.
  * WriteXMLFile1() writes the tree map parameter file.
  */
  void TestTreeMapReading(clSimManager *p_oSimManager);

  /**
  * Makes sure that initial densities are set up correctly.  There are 7 runs.
  * They are as follows:
  * <ul>
  * <li>Run 1:  No trees in the initial densities.  (No trees are
  * created.)</li>
  * <li>Run 2:  No seedlings at all.</li>
  * <li>Run 3:  Seedlings in all three size classes, all species, plus DBH
  * class seedlings.</li>
  * <li>Run 4:  Seedlings in only the first size class, some species.</li>
  * <li>Run 5:  Seedlings in only the second size class, some species.</li>
  * <li>Run 6:  Seedlings in only the third size class, some species.</li>
  * <li>Run 7:  Only seedlings in the DBH size class.</li>
  * </ul>
  * There is a parameter file for each run, WriteXMLFile2 through
  * WriteXMLFile8.
  */
  void TestInitialDensities(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  Bad parameter files are fed in to see if the
  * errors are caught.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for testing.  This contains a tree map to test
  * tree map reading.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file for testing.  This contains no initial densities.
  * @return Filename written.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file for testing.  This contains no seedlings in any
  * form.
  * @return Filename written.
  */
  char * WriteXMLFile3();

  /**
  * Writes a parameter file for testing.  This contains all possible ways of
  * specifying seedlings.
  * @return Filename written.
  */
  char * WriteXMLFile4();

  /**
  * Writes a parameter file for testing.  This contains only seedlings in the
  * first height class.
  * @return Filename written.
  */
  char * WriteXMLFile5();

  /**
  * Writes a parameter file for testing.  This contains only seedlings in the
  * second height class.
  * @return Filename written.
  */
  char * WriteXMLFile6();

  /**
  * Writes a parameter file for testing.  This contains only seedlings in the
  * third height class.
  * @return Filename written.
  */
  char * WriteXMLFile7();

  /**
  * Writes a parameter file for testing.  This contains only seedlings in the
  * DBH class.
  * @return Filename written.
  */
  char * WriteXMLFile8();

  /**
  * Writes a parameter file for error testing.  This contains an initial
  * density value that is negative.
  * @return Filename written.
  */
  char * WriteXMLErrorFile1();

  /**
  * Writes a parameter file for error testing.  This contains an initial
  * density value that cannot be converted into a number.
  * @return Filename written.
  */
  char * WriteXMLErrorFile2();

  /**
  * Writes a parameter file for error testing.  This contains initial
  * densities with no size classes.
  * @return Filename written.
  */
  char * WriteXMLErrorFile3();

  /**
  * Writes a parameter file for error testing.  This contains an initial
  * density value for an unrecognized species.
  * @return Filename written.
  */
  char * WriteXMLErrorFile4();

  /**
  * Writes a parameter file for error testing.  This contains an initial
  * density value with an unrecognized size class.
  * @return Filename written.
  */
  char * WriteXMLErrorFile5();

  /**
  * Writes a parameter file for error testing.  This contains an initial
  * density class that cannot be converted into a number.
  * @return Filename written.
  */
  char * WriteXMLErrorFile6();

  /**
  * Writes a parameter file for error testing.  This contains a seedling height
  * class taller than 135.
  * @return Filename written.
  */
  char * WriteXMLErrorFile7();

  /**
  * Writes a parameter file for error testing.  An upper bound for the first
  * seedling height class is above the value for the upper bound of the second
  * seedling height class for that species.
  * @return Filename written.
  */
  char * WriteXMLErrorFile8();


  /**
  * Writes a common portion of the test parameter files.  This writes from
  * the beginning of the file to "&lt;/plot&gt;".
  * @param oOut File stream to write to.
  */
  void WriteCommonPlotStuff(std::fstream &oOut);

  /**
  * Writes a common portion of the test parameter files.  This writes all
  * tree parameters and the rest of the plot.
  * @param oOut File stream to write to.
  */
  void WriteCommonFileStuff(std::fstream &oOut);

};
//---------------------------------------------------------------------------
#endif // TestTreePopulation2_H
