//---------------------------------------------------------------------------
// TestSubstrate.cpp
//---------------------------------------------------------------------------
#include "TestSubstrate.h"
#include "GridBase.h"
#include "SimManager.h"
#include "BehaviorBase.h"
#include "TreePopulation.h"
#include <math.h>
#include <fstream.h>

/////////////////////////////////////////////////////////////////////////////
//  TestSubstrate()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestSubstrate()
{
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");
  TestSubstrateGridSetup(p_oSimManager);
  TestTreeFall(p_oSimManager);
  TestHarvestSubstrate(p_oSimManager);
  TestSubstrateCalcs(p_oSimManager);
  TestSnagSubstrate(p_oSimManager);
  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
//  TestTreeFall()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestTreeFall(clSimManager *p_oSimManager)
{
  clPopulationBase *p_oTemp;
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  int iNumSp1Snags = 0, iNumSp2Snags = 0, iNumSp3Snags = 0, iSpecies, i;

  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile8());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;

  //Create 1000 of each species of tree, all adults
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::adult, 17);
  }
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 1, clTreePopulation::adult, 17);
  }
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 2, clTreePopulation::adult, 17);
  }

  //Run for 1 timestep
  p_oSimManager->RunSim(1);

  //Count up the trees left over.  They should all be snags.
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Make sure it's not alive
    CPPUNIT_ASSERT(clTreePopulation::snag == p_oTree->GetType());

    //Count it
    iSpecies = p_oTree->GetSpecies();
    if (0 == iSpecies) iNumSp1Snags++;
    else if (1 == iSpecies) iNumSp2Snags++;
    else if (2 == iSpecies) iNumSp3Snags++;

    p_oTree = p_oAllTrees->NextTree();
  }

  //Now make sure we have the number we expect left standing
  CPPUNIT_ASSERT(fabs(iNumSp1Snags - 800)/800 < 0.05);
  CPPUNIT_ASSERT(fabs(iNumSp2Snags - 500)/500 < 0.05);
  CPPUNIT_ASSERT(iNumSp3Snags == 1000);

  //Run another timestep and count them again
  iNumSp1Snags = 0;
  iNumSp2Snags = 0;
  iNumSp3Snags = 0;
  p_oSimManager->RunSim(1);
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Make sure it's not alive
    CPPUNIT_ASSERT(clTreePopulation::snag == p_oTree->GetType());

    //Count it
    iSpecies = p_oTree->GetSpecies();
    if (0 == iSpecies) iNumSp1Snags++;
    else if (1 == iSpecies) iNumSp2Snags++;
    else if (2 == iSpecies) iNumSp3Snags++;

    p_oTree = p_oAllTrees->NextTree();
  }

  //Now make sure we have the number we expect left standing
  CPPUNIT_ASSERT(fabs(iNumSp1Snags - 800)/800 < 0.05);
  CPPUNIT_ASSERT(fabs(iNumSp2Snags - 500)/500 < 0.05);
  CPPUNIT_ASSERT(iNumSp3Snags == 1000);

  //***************************
  // Repeat with longer timestep
  //***************************
  p_oSimManager->ReadFile(WriteXMLFile9());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;

  //Create 1000 of each species of tree, all adults
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::adult, 17);
  }
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 1, clTreePopulation::adult, 17);
  }
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 2, clTreePopulation::adult, 17);
  }

  //Run for 1 timestep
  p_oSimManager->RunSim(1);

  //Count up the trees left over.  They should all be snags
  iNumSp1Snags = 0;
  iNumSp2Snags = 0;
  iNumSp3Snags = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Make sure it's not alive
    CPPUNIT_ASSERT(clTreePopulation::snag == p_oTree->GetType());

    //Count it
    iSpecies = p_oTree->GetSpecies();
    if (0 == iSpecies) iNumSp1Snags++;
    else if (1 == iSpecies) iNumSp2Snags++;
    else if (2 == iSpecies) iNumSp3Snags++;

    p_oTree = p_oAllTrees->NextTree();
  }


  //Now make sure we have the number we expect left standing
  CPPUNIT_ASSERT(fabs(iNumSp1Snags - 512)/512 < 0.05);
  CPPUNIT_ASSERT(fabs(iNumSp2Snags - 125)/125 < 0.05);
  CPPUNIT_ASSERT(iNumSp3Snags == 1000);

  //Run another timestep and count them again
  iNumSp1Snags = 0;
  iNumSp2Snags = 0;
  iNumSp3Snags = 0;
  p_oSimManager->RunSim(1);
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Make sure it's not alive
    CPPUNIT_ASSERT(clTreePopulation::snag == p_oTree->GetType());

    //Count it
    iSpecies = p_oTree->GetSpecies();
    if (0 == iSpecies) iNumSp1Snags++;
    else if (1 == iSpecies) iNumSp2Snags++;
    else if (2 == iSpecies) iNumSp3Snags++;

    p_oTree = p_oAllTrees->NextTree();
  }

  //Now make sure we have the number we expect left standing
  CPPUNIT_ASSERT(fabs(iNumSp1Snags - 512)/512 < 0.05);
  CPPUNIT_ASSERT(fabs(iNumSp2Snags - 125)/125 < 0.05);
  CPPUNIT_ASSERT(iNumSp3Snags == 1000);
}

/////////////////////////////////////////////////////////////////////////////
//  ProduceDecayGraphs()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::ProduceDecayGraphs()
{
  clGridBase * p_oSubstrateGrid;
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");
  clPopulationBase *p_oTemp;
  clTreePopulation *p_oPop;
  clTree *p_oTree;
  float *p_fLoDecayFreshLogs,
        *p_fLoDecayMossyLogs,
        *p_fMedDecayFreshLogs,
        *p_fMedDecayMossyLogs,
        *p_fHiDecayFreshLogs,
        *p_fHiDecayMossyLogs,
        fTemp,
        fDead = -1;
  int iNumTimesteps = 10, i, j, iX = 0, iY = 0;
  fstream oOut;

  p_fLoDecayFreshLogs = new float[iNumTimesteps];
  p_fLoDecayMossyLogs = new float[iNumTimesteps];
  p_fMedDecayFreshLogs = new float[iNumTimesteps];
  p_fMedDecayMossyLogs = new float[iNumTimesteps];
  p_fHiDecayFreshLogs = new float[iNumTimesteps];
  p_fHiDecayMossyLogs = new float[iNumTimesteps];

  oOut.open("Substrate.txt", ios::out | ios::trunc);

  //**********************************
  // Mossy log low decay
  //**********************************
  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile5());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(NULL != p_oSubstrateGrid);

  //"Run" for 10 timesteps - we have to fake this to set the fresh logs the
  //way we want them
  for (i = 1; i <= iNumTimesteps; i++) {
    p_oSimManager->SetCurrentTimestep(i);

    p_oTree = p_oPop->CreateTree(1, 1, 0, 3, 44);
    p_oTree->SetValue(p_oPop->GetFloatDataCode("lgm", p_oTree->GetSpecies(), p_oTree->GetType()), fDead);

    //Now run the substrate behavior and the tree killer
    for (j = 1; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->Action();
    }
    //Now timestep cleanup
    for (j = 0; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->TimestepCleanup();
    }

    //Get the fresh and mossy log values
    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fTemp);
    p_fLoDecayFreshLogs[i-1] = fTemp;

    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fTemp);
    p_fLoDecayMossyLogs[i-1] = fTemp;
  }

  //**********************************
  // Mossy log medium decay
  //**********************************
  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile6());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(NULL != p_oSubstrateGrid);

  //"Run" for 10 timesteps - we have to fake this to set the fresh logs the
  //way we want them
  for (i = 1; i <= iNumTimesteps; i++) {
    p_oSimManager->SetCurrentTimestep(i);

    p_oTree = p_oPop->CreateTree(1, 1, 0, 3, 44);
    p_oTree->SetValue(p_oPop->GetFloatDataCode("lgm", p_oTree->GetSpecies(), p_oTree->GetType()), fDead);

    //Now run the substrate behavior and the tree killer
    for (j = 1; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->Action();
    }
    //Now timestep cleanup
    for (j = 0; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->TimestepCleanup();
    }

    //Get the fresh and mossy log values
    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fTemp);
    p_fMedDecayFreshLogs[i-1] = fTemp;

    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fTemp);
    p_fMedDecayMossyLogs[i-1] = fTemp;
  }

  //**********************************
  // Mossy log hi decay
  //**********************************
  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile7());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(NULL != p_oSubstrateGrid);

  //"Run" for 10 timesteps - we have to fake this to set the fresh logs the
  //way we want them
  for (i = 1; i <= iNumTimesteps; i++) {
    p_oSimManager->SetCurrentTimestep(i);

    p_oTree = p_oPop->CreateTree(1, 1, 0, 3, 44);
    p_oTree->SetValue(p_oPop->GetFloatDataCode("lgm", p_oTree->GetSpecies(), p_oTree->GetType()), fDead);

    //Now run the substrate behavior and the tree killer
    for (j = 1; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->Action();
    }
    //Now timestep cleanup
    for (j = 0; j < p_oSimManager->GetNumberOfBehaviors(); j++) {
      p_oSimManager->GetBehaviorObject(j)->TimestepCleanup();
    }

    //Get the fresh and mossy log values
    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fTemp);
    p_fHiDecayFreshLogs[i-1] = fTemp;

    p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fTemp);
    p_fHiDecayMossyLogs[i-1] = fTemp;
  }

  //Write output
  //Header for our output file
  oOut << "Timestep\tLo Fresh logs\tLo Mossy logs\tMed Fresh logs\tMed Mossy logs\tHi Fresh logs\tHi Mossy logs\n";
  for (i = 0; i < iNumTimesteps; i++) {
    oOut << i+1 << "\t"
         << p_fLoDecayFreshLogs[i] << "\t" << p_fLoDecayMossyLogs[i] << "\t"
         << p_fMedDecayFreshLogs[i] << "\t" << p_fMedDecayMossyLogs[i] << "\t"
         << p_fHiDecayFreshLogs[i] << "\t" << p_fHiDecayMossyLogs[i] << "\n";
  }

  delete[] p_fLoDecayFreshLogs;
  delete[] p_fLoDecayMossyLogs;
  delete[] p_fMedDecayFreshLogs;
  delete[] p_fMedDecayMossyLogs;
  delete[] p_fHiDecayFreshLogs;
  delete[] p_fHiDecayMossyLogs;
}

/////////////////////////////////////////////////////////////////////////////
//  TestSnagSubstrate()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestSnagSubstrate(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clGridBase *p_oSubstrateGrid;
  clTree *p_oTree;
  float fExpectedFreshLog, fExpectedTipUp, fActual;
  int iX, iY, i;
  bool bDead = true;

  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile10());
  //Grab our pointers
  p_oPop = (clTreePopulation*) p_oSimManager->GetPopulationObject("treepopulation");
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");

  //********************************
  //Timestep 1:  Just run.
  //********************************
  p_oSimManager->RunSim(1);

  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.01;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Cell 2
  iX = 0; iY = 1;
  fExpectedFreshLog = 0.01;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Cell 3
  iX = 0; iY = 2;
  fExpectedFreshLog = 0.01;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Cell 4
  iX = 0; iY = 3;
  fExpectedFreshLog = 0.01;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //********************************
  //Timestep 2:
  //********************************
  //Create and then kill certain trees
  //Tree where y = 1
  p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::snag, 20);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 2
  p_oTree = p_oPop->CreateTree(1, 2, 0, clTreePopulation::snag, 40);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 3
  p_oTree = p_oPop->CreateTree(1, 3, 0, clTreePopulation::snag, 55);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 18
  p_oTree = p_oPop->CreateTree(1, 18, 0, clTreePopulation::snag, 15);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 30 - 10 of these trees
  for (i = 0; i < 10; i++) {
    p_oTree = p_oPop->CreateTree(1, 30, 1, clTreePopulation::snag, 15);
    p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);
  }

  //Now run
  p_oSimManager->RunSim(1);

  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.260798425;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  fExpectedTipUp = 0.196459067;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedTipUp) < 0.001);

  //Cell 2
  iX = 0; iY = 1;
  fExpectedFreshLog = 0.009512294;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  fExpectedTipUp = 0.199860049;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedTipUp) < 0.001);

  //Cell 3
  iX = 0; iY = 2;
  fExpectedFreshLog = 0.027049726;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  fExpectedTipUp = 0.198439418;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedTipUp) < 0.001);

  //Cell 4
  iX = 0; iY = 3;
  fExpectedFreshLog = 0.185012817;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //This value is subjected to stochastic processes
  fExpectedTipUp = 0.175037964;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedTipUp)/fExpectedTipUp < 0.5);

}


/////////////////////////////////////////////////////////////////////////////
//  TestSubstrateCalcs()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestSubstrateCalcs(clSimManager *p_oSimManager)
{
  clGridBase * p_oSubstrateGrid, *p_oCalcsGrid;
  clPackage * p_oCohort;
  clPopulationBase *p_oTemp;
  clTreePopulation *p_oPop;
  clTree *p_oTree;
  float fExpectedGapMoss, fExpectedCanMoss, fExpectedOrganic, fExpectedMossyLog,
  fExpectedFreshLog, fActual, fY;
  int iX, iY, i;
  bool bDead = true;

  //Create and feed in the file
  p_oSimManager->ReadFile(WriteXMLFile4());
  //Grab our pointers
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation*) p_oTemp;
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  p_oCalcsGrid = p_oSimManager->GetGridObject("substratecalcs");

  //********************************
  //Timestep 1:  Just run.
  //********************************
  p_oSimManager->RunSim(1);

  //Verify the freshlogs array
  VerifyTimestep1FreshLogArray(p_oCalcsGrid);

  //Verify the new organics
  VerifyTimestep1Organics(p_oCalcsGrid);

  //Verify the cohorts
  VerifyTimestep1Cohorts(p_oSubstrateGrid);

  //Verify the substrate proportions
  VerifyTimestep1SubstrateProportions(p_oSubstrateGrid);

  //********************************
  //Timestep 2:
  //********************************

  //Set the timestep to 2
  p_oSimManager->SetCurrentTimestep(2);

  //Run the harvest behavior
  p_oSimManager->GetBehaviorObject(0)->Action();

  //Create and then kill certain trees within cell 0, 2
  //Tree where y = 18
  p_oTree = p_oPop->CreateTree(1, 18, 0, 3, 20);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 19
  p_oTree = p_oPop->CreateTree(1, 19, 0, 3, 40);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);


  //Now create and then kill certain trees within cell 0, 3
  //Tree where y = 25
  p_oTree = p_oPop->CreateTree(1, 25, 0, 3, 55);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 26
  p_oTree = p_oPop->CreateTree(1, 26, 0, 3, 15);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Tree where y = 27
  p_oTree = p_oPop->CreateTree(1, 27, 0, 2, 8);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);


  //Now run the substrate behavior and the tree killer
  for (i = 2; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    p_oSimManager->GetBehaviorObject(i)->Action();
  }
  //Now timestep cleanup
  for (i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    p_oSimManager->GetBehaviorObject(i)->TimestepCleanup();
  }

  //Verify the freshlogs array
  VerifyTimestep2FreshLogArray(p_oCalcsGrid);

  //Verify the new organics
  VerifyTimestep2Organics(p_oCalcsGrid);

  //Verify the cohorts
  VerifyTimestep2Cohorts(p_oSubstrateGrid);

  //Verify the substrate proportions
  VerifyTimestep2SubstrateProportions(p_oSubstrateGrid);

  //********************************
  //Timestep 3:
  //********************************
  //We have to fake this timestep.  The light behavior will interfere with our
  //ability to kill trees, so we have to skip it.  Set the timestep to 3
  p_oSimManager->SetCurrentTimestep(3);

  //Create and kill a tree in cell 0, 0 where y = 2
  p_oTree = p_oPop->CreateTree(1, 2, 0, 2, 65);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Create and kill a tree in cell 0, 1 where y = 10
  p_oTree = p_oPop->CreateTree(1, 10, 0, 2, 100);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Create and kill a tree in cell 0, 2 where y = 20
  p_oTree = p_oPop->CreateTree(1, 20, 0, 2, 35);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Create and kill a tree in cell 0, 3 where y = 28
  p_oTree = p_oPop->CreateTree(1, 28, 0, 2, 42);
  p_oTree->SetValue(p_oPop->GetBoolDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), bDead);

  //Now run the harvest behavior, substrate behavior and the tree killer
  p_oSimManager->GetBehaviorObject(0)->Action();
  for (i = 2; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    p_oSimManager->GetBehaviorObject(i)->Action();
  }
  //Now timestep cleanup
  for (i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    p_oSimManager->GetBehaviorObject(i)->TimestepCleanup();
  }

  //Verify the freshlogs array
  VerifyTimestep3FreshLogArray(p_oCalcsGrid);

  //Verify the new organics
  VerifyTimestep3Organics(p_oCalcsGrid);

  //Verify the cohorts
  VerifyTimestep3Cohorts(p_oSubstrateGrid);

  //Verify the substrate proportions
  VerifyTimestep3SubstrateProportions(p_oSubstrateGrid);

  //********************************
  //Timestep 4:  Just run.
  //********************************
  p_oSimManager->RunSim(1);

  //Verify the freshlogs array
  VerifyTimestep4FreshLogArray(p_oCalcsGrid);

  //Verify the new organics
  VerifyTimestep4Organics(p_oCalcsGrid);

  //Verify the cohorts
  VerifyTimestep4Cohorts(p_oSubstrateGrid);

  //Verify the substrate proportions
  VerifyTimestep4SubstrateProportions(p_oSubstrateGrid);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep1SubstrateProportions()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep1SubstrateProportions(clGridBase *p_oSubstrateGrid) {
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss,
        fExpectedMossyLog, fExpectedCanopyMoss, fActual;
  int iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.01;
  fExpectedMossyLog = 0.0495;
  fExpectedOrganic = 0.2;
  fExpectedCanopyMoss = 0.7405;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  //Cell 2
  iY = 1;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.01;
  fExpectedMossyLog = 0.0495;
  fExpectedOrganic = 0.2;
  fExpectedCanopyMoss = 0.7405;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 3
  iY = 2;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.01;
  fExpectedMossyLog = 0.0495;
  fExpectedOrganic = 0.2;
  fExpectedCanopyMoss = 0.7405;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 4
  iY = 3;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.01;
  fExpectedMossyLog = 0.0495;
  fExpectedOrganic = 0.2;
  fExpectedCanopyMoss = 0.7405;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 5
  iY = 4;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.01;
  fExpectedMossyLog = 0.0495;
  fExpectedOrganic = 0.2;
  fExpectedCanopyMoss = 0.7405;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep2SubstrateProportions()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep2SubstrateProportions(clGridBase *p_oSubstrateGrid) {
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss,
        fExpectedMossyLog, fExpectedCanopyMoss, fActual;
  int iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedGapMoss = 0.45;
  fExpectedFreshLog = 0.09;
  fExpectedMossyLog = 0;
  fExpectedOrganic = 0.34;
  fExpectedCanopyMoss = 0.12;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 2
  iY = 1;
  fExpectedGapMoss = 0.36;
  fExpectedFreshLog = 0.17;
  fExpectedMossyLog = 0.01;
  fExpectedOrganic = 0.34;
  fExpectedCanopyMoss = 0.12;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  //Cell 3
  iY = 2;
  fExpectedGapMoss = 0.146224932;
  fExpectedFreshLog = 0.167875654;
  fExpectedMossyLog = 0.04;
  fExpectedOrganic = 0.152608487;
  fExpectedCanopyMoss = 0.493290927;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 4
  iY = 3;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.169256747;
  fExpectedMossyLog = 0.022275;
  fExpectedOrganic = 0.198221137;
  fExpectedCanopyMoss = 0.610247116;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 5
  iY = 4;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.009512294;
  fExpectedMossyLog = 0.021787294;
  fExpectedOrganic = 0.199860049;
  fExpectedCanopyMoss = 0.768840363;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep3SubstrateProportions()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep3SubstrateProportions(clGridBase *p_oSubstrateGrid) {
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss,
        fExpectedMossyLog, fExpectedCanopyMoss, fActual;
  int iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedGapMoss = 0.349659363;
  fExpectedFreshLog = 0.239311544;
  fExpectedMossyLog = 0.004389352;
  fExpectedOrganic = 0.313963341;
  fExpectedCanopyMoss = 0.092676401;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 2
  iY = 1;
  fExpectedGapMoss = 0.211791635;
  fExpectedFreshLog = 0.388640914;
  fExpectedMossyLog = 0.012790998;
  fExpectedOrganic = 0.317919875;
  fExpectedCanopyMoss = 0.068856577;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 3
  iY = 2;
  fExpectedGapMoss = 0.1336126;
  fExpectedFreshLog = 0.217329207;
  fExpectedMossyLog = 0.026596636;
  fExpectedOrganic = 0.153865788;
  fExpectedCanopyMoss = 0.468595769;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 4
  iY = 3;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.230107105;
  fExpectedMossyLog = 0.027311351;
  fExpectedOrganic = 0.194422339;
  fExpectedCanopyMoss = 0.548159205;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 5
  iY = 4;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.000108295;
  fExpectedMossyLog = 0.019208282;
  fExpectedOrganic = 0.197261163;
  fExpectedCanopyMoss = 0.783422261;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep4SubstrateProportions()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep4SubstrateProportions(clGridBase *p_oSubstrateGrid) {
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss,
        fExpectedMossyLog, fExpectedCanopyMoss, fActual;
  int iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedGapMoss = 0.346091173;
  fExpectedFreshLog = 0.16508864;
  fExpectedMossyLog = 0.09503663;
  fExpectedOrganic = 0.310493762;
  fExpectedCanopyMoss = 0.083289794;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 2
  iY = 1;
  fExpectedGapMoss = 0.209630353;
  fExpectedFreshLog = 0.280228899;
  fExpectedMossyLog = 0.179936023;
  fExpectedOrganic = 0.315236809;
  fExpectedCanopyMoss = 0.014967917;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 3
  iY = 2;
  fExpectedGapMoss = 0.132249116;
  fExpectedFreshLog = 0.06952284;
  fExpectedMossyLog = 0.181209124;
  fExpectedOrganic = 0.152042738;
  fExpectedCanopyMoss = 0.464976182;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 4
  iY = 3;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.090875207;
  fExpectedMossyLog = 0.168882443;
  fExpectedOrganic = 0.054255551;
  fExpectedCanopyMoss = 0.685986799;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //Cell 5
  iY = 4;
  fExpectedGapMoss = 0;
  fExpectedFreshLog = 0.000108295;
  fExpectedMossyLog = 0.008643727;
  fExpectedOrganic = 0.197261163;
  fExpectedCanopyMoss = 0.793986816;
  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanopyMoss) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep1Cohorts()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep1Cohorts(clGridBase *p_oSubstrateGrid) {
  clPackage * p_oCohort;
  float fExpectedOrganic = 0.2, fExpectedFreshLog = 0.01, fExpectedGapMoss = 0.0, fActual;
  int iX, iY, iAge = 1, iActual;

  //Cell 1
  iX = 0; iY = 0;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 2
  iY = 1;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 3
  iY = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 4
  iY = 3;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 5
  iY = 4;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep2Cohorts()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep2Cohorts(clGridBase *p_oSubstrateGrid) {
  clPackage * p_oCohort;
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss, fActual;
  int iX, iY, iAge, iActual;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedOrganic = 0.34;
  fExpectedFreshLog = 0.09;
  fExpectedGapMoss = 0.45;
  iAge = 1;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 2
  iY = 1;
  fExpectedOrganic = 0.34;
  fExpectedFreshLog = 0.17;
  fExpectedGapMoss = 0.36;
  iAge = 1;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 3
  iY = 2;
  fExpectedOrganic = 0.152608487;
  fExpectedFreshLog = 0.167875654;
  fExpectedGapMoss = 0.146224932;
  iAge = 1;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 4, cohort 1
  iY = 3;
  fExpectedOrganic = 0.160005057;
  fExpectedFreshLog = 0.008000253;
  fExpectedGapMoss = 0.0;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  //Cell 4, cohort 2
  fExpectedOrganic = 0.038328044;
  fExpectedFreshLog = 0.161646671;
  fExpectedGapMoss = 0.0;
  iAge = 1;
  p_oCohort = p_oCohort->GetNextPackage();
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 5
  iY = 4;
  fExpectedOrganic = 0.2;
  fExpectedFreshLog = 0.01;
  fExpectedGapMoss = 0.0;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep3Cohorts()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep3Cohorts(clGridBase *p_oSubstrateGrid) {
  clPackage * p_oCohort;
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss, fActual;
  int iX, iY, iAge, iActual;

  //Cell 1, cohort 1
  iX = 0; iY = 0;
  fExpectedOrganic = 0.264321844;
  fExpectedFreshLog = 0.069967547;
  fExpectedGapMoss = 0.349837735;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  //Cell 1, cohort 2
  fExpectedOrganic = 0.049826457;
  fExpectedFreshLog = 0.172756354;
  fExpectedGapMoss = 0.0;
  iAge = 1;
  p_oCohort = p_oCohort->GetNextPackage();
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 2, cohort 1
  iY = 1;
  fExpectedOrganic = 0.200127472;
  fExpectedFreshLog = 0.100063736;
  fExpectedGapMoss = 0.211899677;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  //Cell 2, cohort 2
  fExpectedOrganic = 0.117932443;
  fExpectedFreshLog = 0.293457344;
  fExpectedGapMoss = 0.0;
  iAge = 1;
  p_oCohort = p_oCohort->GetNextPackage();
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());


  //Cell 3, cohort 1
  iY = 2;
  fExpectedOrganic = 0.139516691;
  fExpectedFreshLog = 0.153474136;
  fExpectedGapMoss = 0.13368076;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  //Cell 3, cohort 2
  fExpectedOrganic = 0.014446724;
  fExpectedFreshLog = 0.071340092;
  fExpectedGapMoss = 0.0;
  iAge = 1;
  p_oCohort = p_oCohort->GetNextPackage();
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 4, cohort 1
  iY = 3;
  fExpectedOrganic = 0.033931489;
  fExpectedFreshLog = 0.143104415;
  fExpectedGapMoss = 0.0;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  //Cell 4, cohort 2
  fExpectedOrganic = 0.020803283;
  fExpectedFreshLog = 0.093905275;
  fExpectedGapMoss = 0.0;
  iAge = 1;
  p_oCohort = p_oCohort->GetNextPackage();
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 5
  iY = 4;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL == p_oCohort);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep4Cohorts()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep4Cohorts(clGridBase *p_oSubstrateGrid) {
  clPackage * p_oCohort;
  float fExpectedOrganic, fExpectedFreshLog, fExpectedGapMoss, fActual;
  int iX, iY, iAge, iActual;

  //Cell 1, cohort 1
  iX = 0; iY = 0;
  fExpectedOrganic = 0.049826457;
  fExpectedFreshLog = 0.172756354;
  fExpectedGapMoss = 0.0;
  iAge = 2;

  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);
  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 2, cohort 1
  iY = 1;
  fExpectedOrganic = 0.117932443;
  fExpectedFreshLog = 0.293457344;
  fExpectedGapMoss = 0.0;
  iAge = 2;

  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 3, cohort 1
  iY = 2;
  fExpectedOrganic = 0.014446724;
  fExpectedFreshLog = 0.071340092;
  fExpectedGapMoss = 0.0;
  iAge = 2;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 4, cohort 1
  iY = 3;
  fExpectedOrganic = 0.020803283;
  fExpectedFreshLog = 0.093905275;
  fExpectedGapMoss = 0.0;
  iAge = 2;

  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageIntDataCode("age"), & iActual);
  CPPUNIT_ASSERT(iActual == iAge);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Cell 5
  iY = 4;
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL == p_oCohort);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep1Organic()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep1Organics(clGridBase *p_oCalcsGrid) {

  float fExpectedOrganics = 0.2, fActual;
  int iCode = p_oCalcsGrid->GetFloatDataCode("neworganics"),
      iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep2Organic()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep2Organics(clGridBase *p_oCalcsGrid) {

  float fExpectedOrganics, fActual;
  int iCode = p_oCalcsGrid->GetFloatDataCode("neworganics"),
      iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedOrganics = 0.34;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedOrganics = 0.34;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedOrganics = 0.173586489;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedOrganics = 0.038328044;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedOrganics = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep3Organic()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep3Organics(clGridBase *p_oCalcsGrid) {

  float fExpectedOrganics, fActual;
  int iCode = p_oCalcsGrid->GetFloatDataCode("neworganics"),
      iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  fExpectedOrganics = 0.049826457;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedOrganics = 0.117932443;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedOrganics = 0.014446724;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedOrganics = 0.020803283;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedOrganics = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep4Organic()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep4Organics(clGridBase *p_oCalcsGrid) {

  float fExpectedOrganics = 0.0, fActual;
  int iCode = p_oCalcsGrid->GetFloatDataCode("neworganics"),
      iX, iY;

  //Cell 1
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, iCode, & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganics) < 0.001);
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep1FreshLogArray()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep1FreshLogArray(clGridBase *p_oCalcsGrid) {
  char cLabel[20];
  float fExpectedFreshLog = 0.01, //all values are the same
        fActual;
  int *p_iFreshLogCodes = new int[3],
       iX, iY, i;

  for ( i = 0; i < 3; i++ )
  {
    sprintf( cLabel, "%s%d", "freshlog_", i );
    p_iFreshLogCodes[i] = p_oCalcsGrid->GetFloatDataCode( cLabel );
    CPPUNIT_ASSERT(-1 < p_iFreshLogCodes[i]);
  }

  //Current timestep addition
  //Cell 1
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Last timestep
  fExpectedFreshLog = 0.0;
  //Cell 1
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Timestep - 2
  //Cell 1
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  delete[] p_iFreshLogCodes;
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep2FreshLogArray()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep2FreshLogArray(clGridBase *p_oCalcsGrid) {
  char cLabel[20];
  float fExpectedFreshLog, //all values are the same
        fActual;
  int *p_iFreshLogCodes = new int[3],
       iX, iY, i;

  for ( i = 0; i < 3; i++ )
  {
    sprintf( cLabel, "%s%d", "freshlog_", i );
    p_iFreshLogCodes[i] = p_oCalcsGrid->GetFloatDataCode( cLabel );
    CPPUNIT_ASSERT(-1 < p_iFreshLogCodes[i]);
  }

  //Current timestep addition
  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.09;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.17;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.176266855;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.161646671;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Last timestep
  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.01;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.01;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Timestep - 2
  //Cell 1
  fExpectedFreshLog = 0.0;
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  delete[] p_iFreshLogCodes;
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep3FreshLogArray()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep3FreshLogArray(clGridBase *p_oCalcsGrid) {
  char cLabel[20];
  float fExpectedFreshLog, //all values are the same
        fActual;
  int *p_iFreshLogCodes = new int[3],
       iX, iY, i;

  for ( i = 0; i < 3; i++ )
  {
    sprintf( cLabel, "%s%d", "freshlog_", i );
    p_iFreshLogCodes[i] = p_oCalcsGrid->GetFloatDataCode( cLabel );
    CPPUNIT_ASSERT(-1 < p_iFreshLogCodes[i]);
  }

  //Current timestep addition
  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.172756354;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.293457344;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.071340092;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.093905275;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Last timestep
  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.09;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.17;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.176266855;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.161646671;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Timestep - 2
  //Cell 1
  fExpectedFreshLog = 0.0;
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  fExpectedFreshLog = 0.0;
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  fExpectedFreshLog = 0.0;
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  fExpectedFreshLog = 0.01;
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  fExpectedFreshLog = 0.01;
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  delete[] p_iFreshLogCodes;
}

/////////////////////////////////////////////////////////////////////////////
//  VerifyTimestep4FreshLogArray()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::VerifyTimestep4FreshLogArray(clGridBase *p_oCalcsGrid) {
  char cLabel[20];
  float fExpectedFreshLog, //all values are the same
        fActual;
  int *p_iFreshLogCodes = new int[3],
       iX, iY, i;

  for ( i = 0; i < 3; i++ )
  {
    sprintf( cLabel, "%s%d", "freshlog_", i );
    p_iFreshLogCodes[i] = p_oCalcsGrid->GetFloatDataCode( cLabel );
    CPPUNIT_ASSERT(-1 < p_iFreshLogCodes[i]);
  }

  //Current timestep addition
  //Cell 1
  fExpectedFreshLog = 0.0;
  iX = 0; iY = 0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[0], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Last timestep
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.172756354;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.293457344;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.071340092;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.093905275;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[1], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  //Timestep - 2
  //Cell 1
  iX = 0; iY = 0;
  fExpectedFreshLog = 0.09;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 2
  iY = 1;
  fExpectedFreshLog = 0.17;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 3
  iY = 2;
  fExpectedFreshLog = 0.176266855;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 4
  iY = 3;
  fExpectedFreshLog = 0.161646671;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);
  //Cell 5
  iY = 4;
  fExpectedFreshLog = 0.0;
  p_oCalcsGrid->GetValueOfCell(iX, iY, p_iFreshLogCodes[2], & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  delete[] p_iFreshLogCodes;
}

/////////////////////////////////////////////////////////////////////////////
//  TestHarvestSubstrate()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestHarvestSubstrate(clSimManager *p_oSimManager)
{
  clGridBase * p_oSubstrateGrid;
  clPackage * p_oCohort;
  float fExpectedGapMoss, fExpectedCanMoss, fExpectedOrganic, fExpectedMossyLog, fExpectedFreshLog, fActual;
  int iX, iY;

  //Feed file # 1 and run it
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oSimManager->RunSim(1);

  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");

  //Verify the substrates of the clear cut cell
  fExpectedGapMoss = 0.36;
  fExpectedCanMoss = 0.12;
  fExpectedOrganic = 0.34;
  fExpectedMossyLog = 0.01;
  fExpectedFreshLog = 0.17;
  iX = 0; iY = 0;

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //There should be one cohort per cell which also matches the clear cut conditions
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);
  CPPUNIT_ASSERT(NULL != p_oCohort);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Verify the substrates of the gap cut cell
  fExpectedGapMoss = 0.45;
  fExpectedCanMoss = 0.12;
  fExpectedOrganic = 0.34;
  fExpectedMossyLog = 0.0;
  fExpectedFreshLog = 0.09;
  iX = 0; iY = 1;

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //There should be one cohort per cell which also matches the clear cut conditions
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Verify the substrates of the partial cut cell
  fExpectedGapMoss = 0.17;
  fExpectedCanMoss = 0.58;
  fExpectedOrganic = 0.15;
  fExpectedMossyLog = 0.04;
  fExpectedFreshLog = 0.06;
  iX = 0; iY = 2;

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedCanMoss) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

  //There should be one cohort per cell which also matches the clear cut conditions
  p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

  p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
  CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

  CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());

  //Clean up
  delete p_oSimManager;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSubstrateGridSetup()
/////////////////////////////////////////////////////////////////////////////
void clTestSubstrate::TestSubstrateGridSetup(clSimManager *p_oSimManager)
{
  clGridBase * p_oSubstrateGrid, *p_oSubstrateCalcsGrid;
  float fVal;

  //Feed file # 1 and make sure grid resolutions are right
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthXCells() - 8) < 0.001);
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthYCells() - 8) < 0.001);

  //Feed file # 2 and make sure grid resolutions are right
  p_oSimManager->ReadFile(WriteXMLFile2());
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthXCells() - 3) < 0.001);
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthYCells() - 2) < 0.001);
  //Make sure the substrate calcs resolutions are right and the values got read
  p_oSubstrateCalcsGrid = p_oSimManager->GetGridObject("substratecalcs");
  CPPUNIT_ASSERT(fabs(p_oSubstrateCalcsGrid->GetLengthXCells() - 3) < 0.001);
  CPPUNIT_ASSERT(fabs(p_oSubstrateCalcsGrid->GetLengthYCells() - 2) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("neworganics"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.1) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_0"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.01) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_1"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.02) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_2"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.03) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_3"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.04) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_4"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.05) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_5"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.06) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_6"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.07) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_7"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.08) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_8"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.09) < 0.001);
  p_oSubstrateCalcsGrid->GetValueOfCell(0, 0, p_oSubstrateCalcsGrid->GetFloatDataCode("freshlog_9"), &fVal);
  CPPUNIT_ASSERT(fabs(fVal - 0.11) < 0.001);

  //Feed file # 3 and make sure grid resolutions are right
  p_oSimManager->ReadFile(WriteXMLFile3());
  p_oSubstrateGrid = p_oSimManager->GetGridObject("Substrate");
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthXCells() - 8) < 0.001);
  CPPUNIT_ASSERT(fabs(p_oSubstrateGrid->GetLengthYCells() - 8) < 0.001);

  //Now check that initial conditions were correctly populated
  clPackage * p_oCohort;
  float fExpectedGapMoss = 0.15, fExpectedCanMoss = 0.37, fExpectedOrganic = 0.2, fExpectedMossyLog = 0.11,
       fExpectedFreshLog = 0.17, fActual;
  int iNumXCells = p_oSubstrateGrid->GetNumberXCells(), iNumYCells = p_oSubstrateGrid->GetNumberYCells(), iX, iY;

  for (iX = 0; iX < iNumXCells; iX++)
  {
    for (iY = 0; iY < iNumYCells; iY++)
    {

      //The values all should match the parameter file initial conditions
      p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("gapmoss"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

      p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("canmoss"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedCanMoss) < 0.001);

      p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("organic"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

      p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("freshlog"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

      p_oSubstrateGrid->GetValueOfCell(iX, iY, p_oSubstrateGrid->GetFloatDataCode("mossylog"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedMossyLog) < 0.001);

      //There should be one cohort per cell which also matches the initial conditions
      p_oCohort = p_oSubstrateGrid->GetFirstPackageOfCell(iX, iY);

      p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("gapmoss"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedGapMoss) < 0.001);

      p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("organic"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedOrganic) < 0.001);

      p_oCohort->GetValue(p_oSubstrateGrid->GetPackageFloatDataCode("freshlog"), & fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpectedFreshLog) < 0.001);

      CPPUNIT_ASSERT(NULL == p_oCohort->GetNextPackage());
    }
  }

  //Clean up
  delete p_oSimManager;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>2</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>" << "<plot_lenY>200.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"3\">" << "<tm_floatCodes>" << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>" << "<tm_floatCode label=\"DBH\">2</tm_floatCode>" << "</tm_floatCodes>"
       << "</tm_treeSettings>" << "<tree sp=\"0\" tp=\"3\">" << "<fl c=\"0\">1</fl>" << "<fl c=\"1\">1</fl>"
       << "<fl c=\"2\">12</fl>" << "</tree>" << "<tree sp=\"0\" tp=\"3\">" << "<fl c=\"0\">1</fl>" << "<fl c=\"1\">9</fl>"
       << "<fl c=\"2\">12</fl>" << "</tree>" << "<tree sp=\"0\" tp=\"3\">" << "<fl c=\"0\">1</fl>" << "<fl c=\"1\">17</fl>"
       << "<fl c=\"2\">12</fl>" << "</tree>" << "</tr_treemap>" << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>" << "<behavior>"
       << "<behaviorName>harvest</behaviorName>" << "<version>1</version>" << "</behavior>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>" << "</behaviorList>" << "<harvest>"
       << "<ha_cutEvent>" << "<ha_applyToSpecies species=\"Species_1\" />" << "<ha_timestep>1</ha_timestep>"
       << "<ha_cutType>clear</ha_cutType>" << "<ha_cutAmountType>percent of density</ha_cutAmountType>" << "<ha_dbhRange>"
       << "<ha_low>0.0</ha_low>" << "<ha_high>3000.0</ha_high>" << "<ha_amountToCut>100.0</ha_amountToCut>"
       << "</ha_dbhRange>" << "<ha_applyToCell x=\"0\" y=\"0\" />" << "</ha_cutEvent>" << "<ha_cutEvent>"
       << "<ha_applyToSpecies species=\"Species_1\" />" << "<ha_timestep>1</ha_timestep>" << "<ha_cutType>gap</ha_cutType>"
       << "<ha_cutAmountType>percent of density</ha_cutAmountType>" << "<ha_dbhRange>" << "<ha_low>0.0</ha_low>"
       << "<ha_high>3000.0</ha_high>" << "<ha_amountToCut>100.0</ha_amountToCut>" << "</ha_dbhRange>"
       << "<ha_applyToCell x=\"0\" y=\"1\" />" << "</ha_cutEvent>" << "<ha_cutEvent>"
       << "<ha_applyToSpecies species=\"Species_1\" />" << "<ha_timestep>1</ha_timestep>"
       << "<ha_cutType>partial</ha_cutType>" << "<ha_cutAmountType>percent of density</ha_cutAmountType>" << "<ha_dbhRange>"
       << "<ha_low>0.0</ha_low>" << "<ha_high>3000.0</ha_high>" << "<ha_amountToCut>100.0</ha_amountToCut>"
       << "</ha_dbhRange>" << "<ha_applyToCell x=\"0\" y=\"2\" />" << "</ha_cutEvent>" << "</harvest>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>" << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>" << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>" << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>" << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>" << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>" << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>" << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>" << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>" << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>" << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>" << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>" << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0.7</su_podfVal>" << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">0.5</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>" << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>" << "<plot_lenY>200.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Substrate\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"gapmoss\">0</ma_floatCode>"
       << "<ma_floatCode label=\"canmoss\">1</ma_floatCode>"
       << "<ma_floatCode label=\"organic\">2</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog\">3</ma_floatCode>"
       << "<ma_floatCode label=\"mossylog\">4</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>3</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"substratecalcs\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"neworganics\">0</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_0\">1</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_1\">2</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_2\">3</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_3\">4</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_4\">5</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_5\">6</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_6\">7</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_7\">8</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_8\">9</ma_floatCode>"
       << "<ma_floatCode label=\"freshlog_9\">10</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>3</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">0.1</fl>"
       << "<fl c=\"1\">0.01</fl>"
       << "<fl c=\"2\">0.02</fl>"
       << "<fl c=\"3\">0.03</fl>"
       << "<fl c=\"4\">0.04</fl>"
       << "<fl c=\"5\">0.05</fl>"
       << "<fl c=\"6\">0.06</fl>"
       << "<fl c=\"7\">0.07</fl>"
       << "<fl c=\"8\">0.08</fl>"
       << "<fl c=\"9\">0.09</fl>"
       << "<fl c=\"10\">0.11</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>" << "<behaviorName>adultstochasticmort</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>substrate</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>" << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>" << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>" << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>" << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.0</su_initialOrganic>" << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>" << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0.7</su_podfVal>" << "</su_propOfDeadFall>" << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">0.5</su_pofuVal>" << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>" << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>" << "<plot_lenY>200.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>" << "<behaviorName>adultstochasticmort</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>substrate</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>" << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>" << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>" << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>10</su_maxNumberDecayYears>" << "<su_initialGapMoss>0.15</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>" << "<su_initialFreshLog>0.17</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0.7</su_podfVal>" << "</su_propOfDeadFall>" << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">0.5</su_pofuVal>" << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.0</su_rootTipupFactor>" << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>4</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>" << "<plot_lenY>200.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"2\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1</fl>"
       << "<fl c=\"1\">1</fl>"
       << "<fl c=\"2\">20</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1</fl>"
       << "<fl c=\"1\">9</fl>"
       << "<fl c=\"2\">20</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1</fl>"
       << "<fl c=\"1\">17</fl>"
       << "<fl c=\"2\">12</fl>"
       << "</tree>"
       << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>" << "<behavior>"
       << "<behaviorName>harvest</behaviorName>" << "<version>1</version>" << "</behavior>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_1\" type=\"Sapling\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<harvest>"
       << "<ha_cutEvent>"
       << "<ha_applyToSpecies species=\"Species_1\" />"
       << "<ha_timestep>2</ha_timestep>"
       << "<ha_cutType>gap</ha_cutType>"
       << "<ha_cutAmountType>percent of density</ha_cutAmountType>"
       << "<ha_dbhRange>"
       << "<ha_low>0.0</ha_low>"
       << "<ha_high>25.0</ha_high>"
       << "<ha_amountToCut>100.0</ha_amountToCut>"
       << "</ha_dbhRange>"
       << "<ha_applyToCell x=\"0\" y=\"0\" />"
       << "</ha_cutEvent>"
       << "<ha_cutEvent>"
       << "<ha_applyToSpecies species=\"Species_1\" />"
       << "<ha_timestep>2</ha_timestep>"
       << "<ha_cutType>clear</ha_cutType>"
       << "<ha_cutAmountType>percent of density</ha_cutAmountType>"
       << "<ha_dbhRange>"
       << "<ha_low>0.0</ha_low>"
       << "<ha_high>25.0</ha_high>"
       << "<ha_amountToCut>100.0</ha_amountToCut>"
       << "</ha_dbhRange>"
       << "<ha_applyToCell x=\"0\" y=\"1\" />"
       << "</ha_cutEvent>"
       << "<ha_cutEvent>"
       << "<ha_applyToSpecies species=\"Species_1\" />"
       << "<ha_timestep>2</ha_timestep>"
       << "<ha_cutType>partial</ha_cutType>"
       << "<ha_cutAmountType>percent of density</ha_cutAmountType>" << "<ha_dbhRange>"
       << "<ha_low>0.0</ha_low>" << "<ha_high>15.0</ha_high>" << "<ha_amountToCut>100.0</ha_amountToCut>" << "</ha_dbhRange>"
       << "<ha_applyToCell x=\"0\" y=\"2\" />" << "</ha_cutEvent>" << "</harvest>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>" << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>" << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>" << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>3</su_maxNumberDecayYears>" << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>" << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>" << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>" << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>" << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>" << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>" << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>" << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>" << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">1</su_podfVal>" << "</su_propOfDeadFall>" << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>" << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>" << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile5()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_1\" type=\"Sapling\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>4.4</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.225</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>50</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.01</su_initialMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">1</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile6()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_1\" type=\"Sapling\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>4.4</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.45</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>50</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.01</su_initialMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">1</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile7()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_1\" type=\"Sapling\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>4.4</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.9</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>50</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.01</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">1</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile8()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Register a behavior for snags
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_3\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">1.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">1.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">1.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>4.4</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.9</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>50</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.01</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0.2</su_podfVal>"
       << "<su_podfVal species=\"Species_2\">0.5</su_podfVal>"
       << "<su_podfVal species=\"Species_3\">0.0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "<su_pofuVal species=\"Species_2\">1</su_pofuVal>"
       << "<su_pofuVal species=\"Species_3\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_3\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile9()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile9()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Register a behavior for snags
       << "<behavior>"
       << "<behaviorName>radiallight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_3\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">1.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">1.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">1.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>"
       << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>"
       << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>"
       << "<su_freshLogDecayBeta>4.4</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.9</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>50</su_maxNumberDecayYears>"
       << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>"
       << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.01</su_initialMossyLog>"
       << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>"
       << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>"
       << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>"
       << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>"
       << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>"
       << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0.2</su_podfVal>"
       << "<su_podfVal species=\"Species_2\">0.5</su_podfVal>"
       << "<su_podfVal species=\"Species_3\">0.0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "<su_pofuVal species=\"Species_2\">1</su_pofuVal>"
       << "<su_pofuVal species=\"Species_3\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0</su_posuVal>"
       << "<su_posuVal species=\"Species_3\">0</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile10()
/////////////////////////////////////////////////////////////////////////////
char * clTestSubstrate::WriteXMLFile10()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>4</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       //Have to have a mortality behavior so dead is registered
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>substrate</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "</behavior>"
       //Let the dead remover get rid of the trees we kill
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_2\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0.0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_2\">0.0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "</mortality>"
       << "<substrate>"
       << "<su_gapmossDecayAlpha>-5.1E-4</su_gapmossDecayAlpha>" << "<su_gapmossDecayBeta>4.4</su_gapmossDecayBeta>"
       << "<su_organicDecayAlpha>-7.0E-4</su_organicDecayAlpha>" << "<su_organicDecayBeta>4.3</su_organicDecayBeta>"
       << "<su_freshLogDecayAlpha>-0.05</su_freshLogDecayAlpha>" << "<su_freshLogDecayBeta>6.5</su_freshLogDecayBeta>"
       << "<su_mossyLogToCanMoss>0.55</su_mossyLogToCanMoss>"
       << "<su_maxNumberDecayYears>3</su_maxNumberDecayYears>" << "<su_initialGapMoss>0.0</su_initialGapMoss>"
       << "<su_initialOrganic>0.2</su_initialOrganic>" << "<su_initialFreshLog>0.01</su_initialFreshLog>"
       << "<su_initialMossyLog>0.11</su_initialMossyLog>" << "<su_partialCutGapMoss>0.17</su_partialCutGapMoss>"
       << "<su_partialCutOrganic>0.15</su_partialCutOrganic>" << "<su_partialCutFreshLog>0.06</su_partialCutFreshLog>"
       << "<su_partialCutMossyLog>0.04</su_partialCutMossyLog>" << "<su_gapCutGapMoss>0.45</su_gapCutGapMoss>"
       << "<su_gapCutOrganic>0.34</su_gapCutOrganic>" << "<su_gapCutFreshLog>0.09</su_gapCutFreshLog>"
       << "<su_gapCutMossyLog>0.0</su_gapCutMossyLog>" << "<su_clearCutGapMoss>0.36</su_clearCutGapMoss>"
       << "<su_clearCutOrganic>0.34</su_clearCutOrganic>" << "<su_clearCutFreshLog>0.17</su_clearCutFreshLog>"
       << "<su_clearCutMossyLog>0.01</su_clearCutMossyLog>"
       << "<su_propOfDeadFall>"
       << "<su_podfVal species=\"Species_1\">0</su_podfVal>"
       << "<su_podfVal species=\"Species_2\">0</su_podfVal>"
       << "</su_propOfDeadFall>"
       << "<su_propOfFallUproot>"
       << "<su_pofuVal species=\"Species_1\">1</su_pofuVal>"
       << "<su_pofuVal species=\"Species_2\">1</su_pofuVal>"
       << "</su_propOfFallUproot>"
       << "<su_propOfSnagsUproot>"
       << "<su_posuVal species=\"Species_1\">1</su_posuVal>"
       << "<su_posuVal species=\"Species_2\">0.5</su_posuVal>"
       << "</su_propOfSnagsUproot>"
       << "<su_rootTipupFactor>3.1</su_rootTipupFactor>"
       << "</substrate>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------
